@@ -27,8 +27,12 @@
 #define BATCH_HDR_IMPL_H
 
 #include <QDialog>
+#include <QFuture>
+#include <QFutureWatcher>
 
 #include "Common/LuminanceOptions.h"
+#include "Common/ProgressHelper.h"
+#include "HdrWizard/HdrCreationManager.h"
 
 // Forward declaration
 class IOWorker;
@@ -47,6 +51,9 @@ public:
 	BatchHDRDialog(QWidget *parent = 0);
 	~BatchHDRDialog();
 
+signals:
+    void setValue(int);
+
 protected slots:
 	void num_bracketed_changed(int);
 	void on_selectInputFolder_clicked();
@@ -54,14 +61,20 @@ protected slots:
 	void add_output_directory(QString dir = QString());
 	void on_startButton_clicked();
 	void batch_hdr();
-	void align(QStringList);
+	void align();
 	void create_hdr(int);
 	void error_while_loading(QString);
 	void writeAisData(QByteArray);
 	void check_start_button();
 	void on_cancelButton_clicked();
+    void align_selection_clicked();
 	void processed();
 	void try_to_continue();
+    void updateThresholdSlider(int);
+    void updateThresholdSpinBox(double);
+    void ais_failed(QProcess::ProcessError);
+    void createHdrFinished();
+    void loadFilesAborted();
 
 protected:
 	LuminanceOptions m_luminance_options;
@@ -81,6 +94,10 @@ protected:
 	bool m_loading_error;
 	bool m_abort;
 	bool m_processing;
+	QVector<config_triple> m_customConfig;
+    QFutureWatcher<void> m_futureWatcher;
+    QFuture<pfs::Frame*> m_future;
+    ProgressHelper m_ph;
+    bool m_patches[agGridSize][agGridSize];
 };
-
 #endif
