@@ -24,17 +24,16 @@
  */
 
 #include "BatchTM/BatchTMJob.h"
-#include "Fileformat/pfstiff.h"
 #include "Exif/ExifOperations.h"
+#include "Libpfs/progress.h"
 #include "Libpfs/frame.h"
-#include "Filter/pfscut.h"
-#include "Filter/pfsgamma.h"
+#include "Libpfs/manip/copy.h"
+#include "Libpfs/manip/resize.h"
+#include "Libpfs/manip/gamma.h"
+#include "Libpfs/tm/TonemapOperator.h"
+
 #include "Core/IOWorker.h"
 #include "Common/LuminanceOptions.h"
-#include "Fileformat/pfsout16bitspixmap.h"
-#include "Fileformat/pfsoutldrimage.h"
-#include "TonemappingEngine/TonemapOperator.h"
-#include "Filter/pfssize.h"
 
 #include <QFileInfo>
 #include <QByteArray>
@@ -42,13 +41,14 @@
 #include <QImage>
 #include <QScopedPointer>
 
-BatchTMJob::BatchTMJob(int thread_id, QString filename, const QList<TonemappingOptions*>* tm_options, QString output_folder):
+BatchTMJob::BatchTMJob(int thread_id, const QString &filename, const QList<TonemappingOptions*>* tm_options, const QString &output_folder, const QString &format):
         m_thread_id(thread_id),
         m_file_name(filename),
         m_tm_options(tm_options),
-        m_output_folder(output_folder)
+        m_output_folder(output_folder),
+		m_ldr_output_format(format)
 {
-    m_ldr_output_format = LuminanceOptions().getBatchTmLdrFormat();
+    //m_ldr_output_format = LuminanceOptions().getBatchTmLdrFormat();
 
     m_output_file_name_base  = m_output_folder + "/" + QFileInfo(m_file_name).completeBaseName();
 }
@@ -58,7 +58,7 @@ BatchTMJob::~BatchTMJob()
 
 void BatchTMJob::run()
 {
-    ProgressHelper prog_helper;
+    pfs::Progress prog_helper;
     IOWorker io_worker;
 
     emit add_log_message(tr("[T%1] Start processing %2").arg(m_thread_id).arg(QFileInfo(m_file_name).completeBaseName()));
@@ -85,23 +85,29 @@ void BatchTMJob::run()
 
             QScopedPointer<pfs::Frame> temporary_frame;
             if ( opts->origxsize == opts->xsize )
-                temporary_frame.reset( pfs::pfscopy(reference_frame.data()) );
+            {
+                temporary_frame.reset( pfs::copy(reference_frame.data()) );
+            }
             else
-                temporary_frame.reset( pfs::resizeFrame(reference_frame.data(), opts->xsize) );
+            {
+                temporary_frame.reset( pfs::resize(reference_frame.data(), opts->xsize) );
+            }
 
 			if ( opts->pregamma != 1.0f )
 			{
-				pfs::applyGammaOnFrame(temporary_frame.data(), opts->pregamma );
+                pfs::applyGamma(temporary_frame.data(), opts->pregamma );
 			}
 
             QScopedPointer<TonemapOperator> tm_operator( TonemapOperator::getTonemapOperator(opts->tmoperator) );
 
-            tm_operator->tonemapFrame(temporary_frame.data(), opts, prog_helper);
+            tm_operator->tonemapFrame(*temporary_frame, opts, prog_helper);
 
-            TMOptionsOperations operations(opts);
-            QString output_file_name = m_output_file_name_base+"_"+operations.getPostfix()+"."+m_ldr_output_format;
+            QString output_file_name = m_output_file_name_base+"_"+opts->getPostfix()+"."+m_ldr_output_format;
 
-            if ( io_worker.write_ldr_frame(temporary_frame.data(), output_file_name, opts->quality, opts) )
+            if ( io_worker.write_ldr_frame(temporary_frame.data(),
+                                           output_file_name, QString(),
+                                           QVector<float>(), opts,
+                                           pfs::Params("quality", (size_t)opts->quality)) )
             {
                 emit add_log_message( tr("[T%1] Successfully saved LDR file: %2").arg(m_thread_id).arg(QFileInfo(output_file_name).completeBaseName()) );
             } else {
