@@ -36,108 +36,135 @@
 #include <QStringList>
 #include <QDir>
 
-class LuminanceOptions: public QSettings
+class LuminanceOptions: public QObject
 {
     Q_OBJECT
 public:
     explicit LuminanceOptions();
+    ~LuminanceOptions();
+
+    void setValue(const QString& key, const QVariant& value);
+    QVariant value(const QString & key, const QVariant& defaultValue = QVariant()) const;
+
+    static void conditionallyDoUpgrade();
+
+    static bool isCurrentPortableMode;
+    QString getDatabaseFileName();
+    void    setPortableMode(bool isPortable);
+    
+    bool checkForUpdate();
+    void setUpdateChecked();
 
 public Q_SLOTS:
     // RAW settings
-    bool    isRawFourColorRGB();
+    bool    isRawFourColorRGB() const;
     void    setRawFourColorRGB(bool);
-    bool    isRawDoNotUseFujiRotate();
+    bool    isRawDoNotUseFujiRotate() const;
     void    setRawDoNotUseFujiRotate(bool);
-    double  getRawAber0();
+
+    // Chromatic Aberation
+    bool    isRawUseChromaAber() const;
+    void    setRawUseChromaAber(bool);
+    double  getRawAber0() const;
     void    setRawAber0(double);
-    double  getRawAber1();
+    double  getRawAber1() const;
     void    setRawAber1(double);
-    double  getRawAber2();
+    double  getRawAber2() const;
     void    setRawAber2(double);
-    double  getRawAber3();
+    double  getRawAber3() const;
     void    setRawAber3(double);
-    double  getRawGamm0();
+    double  getRawGamm0() const;
     void    setRawGamm0(double);
-    double  getRawGamm1();
+    double  getRawGamm1() const;
     void    setRawGamm1(double);
-    int     getRawTemperatureKelvin();
-    void    setRawTemperatureKelvin(int);
-    float   getRawGreen();
-    void    setRawGreen(float);
-    float   getRawUserMul0();
-    void    setRawUserMul0(float);
-    float   getRawUserMul1();
-    void    setRawUserMul1(float);
-    float   getRawUserMul2();
-    void    setRawUserMul2(float);
-    float   getRawUserMul3();
-    void    setRawUserMul3(float);
-    bool    isRawAutoBrightness();
-    void    setRawAutoBrightness(bool);
-    float   getRawBrightness();
-    void    setRawBrightness(float f);
-    int     getRawHalfSize();
-    void    setRawHalfSize(int);
-    int     getRawWhiteBalanceMethod();
+    // ---
+    // White Balance
+    int     getRawWhiteBalanceMethod() const;
     void    setRawWhiteBalanceMethod(int);
-    int     getRawOutputColor();
+    int     getRawTemperatureKelvin() const;
+    void    setRawTemperatureKelvin(int);
+    float   getRawGreen() const;
+    void    setRawGreen(float);
+    float   getRawUserMul0() const;
+    void    setRawUserMul0(float);
+    float   getRawUserMul1() const;
+    void    setRawUserMul1(float);
+    float   getRawUserMul2() const;
+    void    setRawUserMul2(float);
+    float   getRawUserMul3() const;
+    void    setRawUserMul3(float);
+    // ----
+    // Brightness
+    bool    isRawAutoBrightness() const;
+    void    setRawAutoBrightness(bool);
+    float   getRawAutoBrightnessThreshold() const;
+    void    setRawAutoBrightnessThreshold(float);
+    float   getRawBrightness() const;
+    void    setRawBrightness(float f);
+    // ---
+    // Noise Reduction
+    // ---
+    int     getRawHalfSize() const;
+    void    setRawHalfSize(int);
+    int     getRawOutputColor() const;
     //void    setRawOutputColor(int);
-    QString getRawOutputProfile();
-    void    setRawOutputProfile(QString);
-    QString getRawCameraProfile();
-    void    setRawCameraProfile(QString);
-    int     getRawUserFlip();
+    QString getRawOutputProfile() const;
+    void    setRawOutputProfile(const QString&);
+    QString getRawCameraProfile() const;
+    void    setRawCameraProfile(const QString&);
+    int     getRawUserFlip() const;
     //void    setRawUserFlip(int);
-    int     getRawUserQuality();
+    int     getRawUserQuality() const;
     void    setRawUserQuality(int);
-    int     getRawMedPasses();
+    int     getRawMedPasses() const;
     void    setRawMedPasses(int);
-    int     getRawHighlightsMode();
+    // Highlights
+    int     getRawHighlightsMode() const;
     void    setRawHighlightsMode(int);
-    int     getRawLevel();
+    int     getRawLevel() const; // reconstruction level
     void    setRawLevel(int);
-    float   getRawBrightnessThreshold();
-    void    setRawBrightnessThreshold(float);
-    float   getRawMaximumThreshold();
+    // ---
+    float   getRawMaximumThreshold() const;
     void    setRawMaximumThreshold(float);
-    bool    isRawUseBlack();
+
+    // Black/White Point
+    bool    isRawUseBlack() const;
     void    setRawUseBlack(bool);
-    int     getRawUserBlack();
+    int     getRawUserBlack() const;
     void    setRawUserBlack(int);
-    bool    isRawUseSaturation();
+    bool    isRawUseSaturation() const;
     void    setRawUseSaturation(bool);
-    int     getRawUserSaturation();
+    int     getRawUserSaturation() const;
     void    setRawUserSaturation(int);
-    bool    isRawUseNoiseReduction();
+    // ---
+    // Noise Reduction
+    bool    isRawUseNoiseReduction() const;
     void    setRawUseNoiseReduction(bool);
-    float   getRawNoiseReductionThreshold();
+    float   getRawNoiseReductionThreshold() const;
     void    setRawNoiseReductionThreshold(float);
-    bool    isRawUseChroma();
-    void    setRawUseChroma(bool);
+    // ---
 
     // Language
     // 2-chars ISO 639 language code for Luminance's user interface
     QString getGuiLang();
-    void    setGuiLang(QString);
+    void    setGuiLang(const QString&);
 
     // Batch HDR
-    QString getBatchHdrPathInput(QString defaultPath = QDir::currentPath());
-    QString getBatchHdrPathOutput(QString defaultPath = QDir::currentPath());
-    void    setBatchHdrPathInput(QString);
-    void    setBatchHdrPathOutput(QString);
+    QString getBatchHdrPathInput(const QString& defaultPath = QDir::currentPath());
+    QString getBatchHdrPathOutput(const QString& defaultPath = QDir::currentPath());
+    void    setBatchHdrPathInput(const QString&);
+    void    setBatchHdrPathOutput(const QString&);
 
     // Batch TM
     QString getBatchTmPathHdrInput();
     QString getBatchTmPathTmoSettings();
     QString getBatchTmPathLdrOutput();
     int     getBatchTmNumThreads();
-    QString getBatchTmLdrFormat();
 
-    void    setBatchTmPathHdrInput(QString);
-    void    setBatchTmPathTmoSettings(QString);
-    void    setBatchTmPathLdrOutput(QString);
+    void    setBatchTmPathHdrInput(const QString&);
+    void    setBatchTmPathTmoSettings(const QString&);
+    void    setBatchTmPathLdrOutput(const QString&);
     void    setBatchTmNumThreads(int);
-    void    setBatchTmLdrFormat(QString);
 
     int     getNumThreads() { return getBatchTmNumThreads(); }
     void    setNumThreads(int i) { setBatchTmNumThreads(i); }
@@ -150,24 +177,23 @@ public Q_SLOTS:
     // Default Paths
     // Path to save temporary cached files
     QString getTempDir();
-    QString getDefaultPathHdrInOut();
-    QString getDefaultPathLdrIn(); // HdrWizard
-    QString getDefaultPathLdrOut();
+    QString getDefaultPathHdrIn();      // MainWindow
+    QString getDefaultPathHdrOut();     // MainWindow
+    QString getDefaultPathLdrIn();      // HdrWizard
+    QString getDefaultPathLdrOut();     // MainWindow
     QString getDefaultPathTmoSettings();
 
-    void    setTempDir(QString path);
-    void    setDefaultPathHdrInOut(QString);
-    void    setDefaultPathLdrIn(QString); // HdrWizard
-    void    setDefaultPathLdrOut(QString);
-    void    setDefaultPathTmoSettings(QString);
+    void    setTempDir(const QString&);
+    void    setDefaultPathHdrIn(const QString&);
+    void    setDefaultPathHdrOut(const QString&);
+    void    setDefaultPathLdrIn(const QString&);    // HdrWizard
+    void    setDefaultPathLdrOut(const QString&);
+    void    setDefaultPathTmoSettings(const QString&);
 
     // HdrWizard
     // commandline options for align_image_stack
     QStringList getAlignImageStackOptions();
-    void        setAlignImageStackOptions(QStringList);
-    // if true always show first page of hdr wizard
-    bool    isShowFirstPageWizard();
-    void    setShowFirstPageWizard(bool b);
+    void        setAlignImageStackOptions(const QStringList&);
 
     bool    isShowFattalWarning();
     void    setShowFattalWarning(bool b);
@@ -179,8 +205,8 @@ public Q_SLOTS:
     // Viewer
     unsigned int getViewerNanInfColor();
     unsigned int getViewerNegColor();
-    void setViewerNanInfColor(unsigned int);
-    void setViewerNegColor(unsigned int);
+    void    setViewerNanInfColor(unsigned int);
+    void    setViewerNegColor(unsigned int);
 
     // Preview Panel
     bool    isPreviewPanelActive();
@@ -189,15 +215,26 @@ public Q_SLOTS:
     int     getPreviewWidth();
     void    setPreviewWidth(int);
 
+    // Realtime Previews
+    bool    isRealtimePreviewsActive();
+    void    setRealtimePreviewsActive(bool);
+
 	// Color Management
 	QString getCameraProfileFileName();
-	void	setCameraProfileFileName(QString);
+    void	setCameraProfileFileName(const QString&);
 
 	QString getMonitorProfileFileName();
-	void	setMonitorProfileFileName(QString);
+    void	setMonitorProfileFileName(const QString&);
 
 	QString getPrinterProfileFileName();
-	void	setPrinterProfileFileName(QString);
+    void	setPrinterProfileFileName(const QString&);
+
+    int     getPreviewPanelMode();
+    void    setPreviewPanelMode(int);
+
+private:
+    void initSettings();
+    QSettings* m_settingHolder;         
 };
 
 #endif
