@@ -31,29 +31,51 @@
 #include <iostream>
 
 #include "Common/config.h"
-
-#include "Common/LuminanceOptions.h"
+#include "Common/global.hxx"
 #include "Common/global.h"
-#include "global.hxx"
+#include "Common/LuminanceOptions.h"
 
-bool matchesLdrFilename(QString file)
+
+bool matchesLdrFilename(const QString& file)
 {
 	QRegExp exp(".*\\.(jpeg|jpg|tiff|tif|crw|cr2|nef|dng|mrw|orf|kdc|dcr|arw|raf|ptx|pef|x3f|raw|sr2|rw2)$", Qt::CaseInsensitive);
 	return exp.exactMatch(file);
 }
 
-bool matchesHdrFilename(QString file)
+bool matchesHdrFilename(const QString& file)
 {
+#ifdef HAVE_CCFITS
+	QRegExp exp(".*\\.(exr|hdr|pic|tiff|tif|fit|fits|pfs|crw|cr2|nef|dng|mrw|orf|kdc|dcr|arw|raf|ptx|pef|x3f|raw|sr2|rw2)$", Qt::CaseInsensitive);
+#else
 	QRegExp exp(".*\\.(exr|hdr|pic|tiff|tif|pfs|crw|cr2|nef|dng|mrw|orf|kdc|dcr|arw|raf|ptx|pef|x3f|raw|sr2|rw2)$", Qt::CaseInsensitive);
+#endif
 	return exp.exactMatch(file);
 }
 
-bool matchesValidHDRorLDRfilename(QString file)
+QStringList getAllHdrFileExtensions()
+{
+    QStringList listAll;
+    QStringList list;
+    list << ".exr" << ".hdr" << ".pic" << ".tiff" << ".tif";
+#if HAVE_CCFITS
+    list << ".fit" << ".fits";
+#endif
+    list << ".pfs" << ".crw" << ".cr2" << ".nef" << ".dng" << ".mrw" << ".orf" << ".kdc" << ".dcr" << ".arw" << ".raf" << ".ptx" << ".pef" << ".x3f" << ".raw" << ".rw2" << ".sr2" << ".3fr" << ".mef" << ".mos" << ".erf" << ".nrw" << ".srw";
+
+    foreach(QString s, list)
+    {
+        listAll << s;
+        listAll << s.toUpper();
+    }
+    return listAll;
+}
+
+bool matchesValidHDRorLDRfilename(const QString& file)
 {
 	return matchesLdrFilename(file) || matchesHdrFilename(file);
 }
 
-QStringList convertUrlListToFilenameList(QList<QUrl> urls)
+QStringList convertUrlListToFilenameList(const QList<QUrl>& urls)
 {
     QStringList files;
     for (int i = 0; i < urls.size(); ++i)
@@ -66,48 +88,3 @@ QStringList convertUrlListToFilenameList(QList<QUrl> urls)
     }
     return files;
 }
-
-namespace
-{
-typedef QScopedPointer<QTranslator> ScopedQTranslator;
-
-ScopedQTranslator lastGuiTranslator;
-ScopedQTranslator lastQtTranslator;
-}
-
-void installTranslators(const QString& lang, bool installQtTranslations)
-{
-    if (lastGuiTranslator)
-    {
-        QCoreApplication::removeTranslator(lastGuiTranslator.data());
-        lastGuiTranslator.reset();
-	}
-    if (installQtTranslations && lastQtTranslator)
-    {
-        QCoreApplication::removeTranslator(lastQtTranslator.data());
-        lastQtTranslator.reset();
-	}
-    if (lang != "en")
-    {
-        ScopedQTranslator guiTranslator( new QTranslator() );
-
-        guiTranslator->load(QString("lang_") + lang, I18NDIR);
-        QCoreApplication::installTranslator(guiTranslator.data());
-        lastGuiTranslator.swap( guiTranslator );
-
-        if (installQtTranslations)
-        {
-            ScopedQTranslator qtTranslator( new QTranslator() );
-
-			qtTranslator->load(QString("qt_") + lang, I18NDIR);
-            QCoreApplication::installTranslator(qtTranslator.data());
-            lastQtTranslator.swap( qtTranslator );
-	    }
-	}
-}
-
-void installTranslators(bool installQtTranslations)
-{
-	LuminanceOptions luminance_options;
-	installTranslators(luminance_options.getGuiLang(), installQtTranslations);
-}
