@@ -39,24 +39,29 @@
 #include <QObject>
 #include <QString>
 
-#include "Common/FloatRgbToQRgb.h"
+#include <Libpfs/params.h>
+#include <Libpfs/colorspace/rgbremapper_fwd.h>
 
-// Forward declaration
 namespace pfs {
-    class Frame;
+class Frame;
 }
 
 class GenericViewer;
 class TonemappingOptions;
+class LuminanceOptions;
 
 int progress_cb(void *data, enum LibRaw_progress p, int iteration, int expected);
 
+pfs::Params getRawSettings();
+pfs::Params getRawSettings(const LuminanceOptions& opts);
+
 class IOWorker : public QObject
 {
     Q_OBJECT
 
 private:
-    friend int progress_cb(void *data, enum LibRaw_progress p, int iteration, int expected);
+    friend
+    int progress_cb(void *data, enum LibRaw_progress p, int iteration, int expected);
 
     void get_frame(QString fname);
     void emitNextStep(int iteration);
@@ -69,22 +74,28 @@ public:
 public Q_SLOTS:
     pfs::Frame* read_hdr_frame(const QString& filename);
 
-    bool write_hdr_frame(pfs::Frame *frame, const QString& filename);
-    bool write_hdr_frame(GenericViewer* frame, const QString& filename);
+    bool write_hdr_frame(pfs::Frame *frame, const QString& filename,
+                         const pfs::Params& params = pfs::Params());
+    bool write_hdr_frame(GenericViewer* frame, const QString& filename,
+                         const pfs::Params& params = pfs::Params());
 
     bool write_ldr_frame(pfs::Frame* frame,
-                         const QString& filename, int quality,
+                         const QString& filename,
+                         const QString& inputFileName,
+                         const QVector<float>& expoTimes,
                          TonemappingOptions* tmopts = NULL,
-                         float min_luminance = 0.0f,
-                         float max_luminance = 1.0f,
-                         LumMappingMethod mapping_method = MAP_LINEAR);
+                         const pfs::Params& params = pfs::Params());
+
     bool write_ldr_frame(GenericViewer* frame,
-                         const QString& filename, int quality,
-                         TonemappingOptions* tmopts = NULL);
+                         const QString& filename,
+                         const QString& inputFileName,
+                         const QVector<float>& expoTimes,
+                         TonemappingOptions* tmopts = NULL,
+                         const pfs::Params& params = pfs::Params());
 
 signals:
-    void read_hdr_failed(const QString& error_message);
-    void read_hdr_success(pfs::Frame*, const QString& fname);
+    void read_hdr_failed(const QString&);
+    void read_hdr_success(pfs::Frame*, const QString&);
 
     void write_hdr_failed();
     void write_hdr_success(pfs::Frame*, const QString&);
