@@ -23,15 +23,35 @@
 #ifndef EXIFOPS_H
 #define EXIFOPS_H
 
-#include <QString>
-#include <exif.hpp>
+#include <string>
 
 namespace ExifOperations
 {
-	void writeExifData(const std::string& filename, const std::string& comment, float expotime = 100.0f);
-	void copyExifData(const std::string& from, const std::string& to, bool dont_overwrite);
-	float obtain_avg_lum(const std::string& filename);
-	int obtain_rotation(const std::string& filename);
+//!
+//!
+void copyExifData(const std::string& from, const std::string& to,
+                  bool dont_overwrite,
+                  const std::string& comment = std::string(),
+                  bool destIsLDR = false,
+                  bool keepRotation = true);
+
+//!
+//!
+int obtain_rotation(const std::string& filename);
+
+//!
+//!
+// float obtain_avg_lum(const std::string& filename);
+
+// //! \brief retrieve exposure bias from \c filename
+// float getExposureBias(const std::string& filename);
+
+//! \brief compute average luminance from exposure bias
+//! \return Average Luminance (as 2^EV) or -1 if the value cannot be calculated
+float getAverageLuminance(const std::string& filename);
+
+float getExposureTime(const std::string& filename);
+
 }
 
 #endif
