@@ -1,12 +1,9 @@
-/**
- * @brief Standard response functions
- *
- * 
+/*
  * This file is a part of Luminance HDR package
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2004 Grzegorz Krawczyk
  * Copyright (C) 2006-2007 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -20,65 +17,92 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
- * 
- * @author Grzegorz Krawczyk, <gkrawczyk@users.sourceforge.net>
- * @author Giuseppe Rota <grota@users.sourceforge.net>
- *
- * $Id: responses.cpp,v 1.6 2006/09/13 14:27:06 gkrawczyk Exp $
+ * ----------------------------------------------------------------------
  */
 
-#ifndef RESPONSES_H
-#define RESPONSES_H
+//! \brief Standard response functions
+//! \author Grzegorz Krawczyk, <gkrawczyk@users.sourceforge.net>
+//! \author Giuseppe Rota <grota@users.sourceforge.net>
+//! \author Davide Anastasia <davideanastasia@users.sourceforge.net>
+//!  Rewrite for LibHDR
 
-#include <stdio.h>
+#ifndef LIBHDR_FUSION_RESPONSES_H
+#define LIBHDR_FUSION_RESPONSES_H
 
-#include <vector>
-#include "Libpfs/array2d.h"
+#include <string>
 
-/**
- * @brief Container for images taken with different exposures
- */
-struct Exposure
-{
-  float ti;			// exposure value (eg time)
-  pfs::Array2D* yi;		// exposed pixel value (camera output)
+namespace libhdr {
+namespace fusion {
+
+enum ResponseFunction {
+    RESPONSE_GAMMA,
+    RESPONSE_LINEAR,
+    RESPONSE_LOG10,
+    RESPONSE_SRGB
 };
 
+class IResponseFunction {
+public:
+    static ResponseFunction fromString(const std::string& type);
 
-/**
- * @brief Container for a list of exposures
- */
-typedef std::vector<Exposure> ExposureList;
-typedef std::vector<pfs::Array2D*> Array2DList;
+    virtual ~IResponseFunction() {}
 
-/**
- * @brief Weighting function with "flat" distribution (as in icip06)
- *
- * @param w [out] weights (array size of M)
- * @param M number of camera output levels
- */
-void exposure_weights_icip06( float* w, int M, int Mmin, int Mmax );
+    //! \brief return the response of the value \c input. \c input is in the
+    //! range [0, 1]
+    virtual float getResponse(float input) const = 0;
 
-/**
- * @brief Weighting function with triangle distribution (as in debevec)
- *
- * @param w [out] weights (array size of M)
- * @param M number of camera output levels
- */
-void weights_triangle( float* w, int M/*, int Mmin, int Mmax */);
+    //! \return type of response function implemented
+    virtual ResponseFunction getType() const = 0;
+};
 
-/**
- * @brief Weighting function with gaussian distribution
- *
- * @param w [out] weights (array size of M)
- * @param M number of camera output levels
- * @param Mmin minimum registered camera output level
- * @param Mmax maximum registered camera output level
- * @param sigma sigma value for gaussian
- */
-void weightsGauss( float* w, int M, int Mmin, int Mmax, float sigma );
+class ResponseGamma : public IResponseFunction
+{
+public:
+    float getResponse(float input) const;
 
+    ResponseFunction getType() const {
+        return RESPONSE_GAMMA;
+    }
+};
+
+class ResponseLinear : public IResponseFunction
+{
+public:
+    float getResponse(float input) const {
+        return input;
+    }
+
+    ResponseFunction getType() const {
+        return RESPONSE_LINEAR;
+    }
+};
+
+class ResponseLog10 : public IResponseFunction
+{
+public:
+    float getResponse(float input) const;
+
+    ResponseFunction getType() const {
+        return RESPONSE_LOG10;
+    }
+};
+
+class ResponseSRGB : public IResponseFunction
+{
+public:
+    float getResponse(float input) const;
+
+    ResponseFunction getType() const {
+        return RESPONSE_SRGB;
+    }
+};
+
+}   // fusion
+}   // libhdr
+
+// Old Stuff
+
+#include <cstdio>
 
 /**
  * @brief Create gamma response function
