@@ -20,7 +20,7 @@
  *
  * Original Work
  * @author Giuseppe Rota <grota@users.sourceforge.net>
- * Improvements, bugfixing
+ * Improvements, bugfixing, anti-ghosting
  * @author Franco Comida <fcomida@users.sourceforge.net>
  *
  */
@@ -28,11 +28,12 @@
 #ifndef EDITINGTOOLS_H
 #define EDITINGTOOLS_H
 
+#include <QMap>
+
 #include "ui_EditingTools.h"
 #include "PreviewWidget.h"
 #include "Common/global.h"
-#include "Viewers/SelectionTool.h"
-#include "HdrCreation/HdrCreationManager.h"
+#include "HdrWizard/HdrCreationManager.h"
 #include "Common/LuminanceOptions.h"
 
 class HistogramLDR;
@@ -42,32 +43,46 @@ class EditingTools : public QDialog, private Ui::EditingToolsDialog
 {
 Q_OBJECT
 public:
-	EditingTools(HdrCreationManager *, QWidget *parent=0);
+	EditingTools(HdrCreationManager *, bool autoAg, QWidget *parent=0);
 	~EditingTools();
+    bool isAutoAntighostingEnabled()   { return m_doAutoAntighosting == true; }
+    bool isManualAntighostingEnabled() { return m_doManualAntighosting == true; }
+    int getAgGoodImageIndex()          { return m_agGoodImageIndex; }
 protected:
 	void keyPressEvent(QKeyEvent *);
 	void keyReleaseEvent(QKeyEvent *);
 private:
-	QList<QImage*> original_ldrlist;
-	QStringList filelist;
-	HdrCreationManager *hcm;
+	QList<QImage*> m_originalImagesList;
+	QList<QImage*> m_antiGhostingMasksList;
+    QImage* m_antiGhostingMask;
+    int m_currentAgMaskIndex;
+	QStringList m_fileList;
+	HdrCreationManager *m_hcm;
+    QMap<QString, int> m_filesMap;
+	QScrollArea *m_scrollArea;
+	PreviewWidget *m_previewWidget;
+	int m_additionalShiftValue;
+	QList< QPair<int,int> > m_HV_offsets;
+	HistogramLDR *m_histogram;
+	QSize m_previousPreviewWidgetSize;
+	bool m_imagesSaved;
+    int m_agGoodImageIndex;
+    bool m_antiGhosting;
+	LuminanceOptions m_luminanceOptions;
+	QVector<float> m_expotimes;
+    bool m_patches[agGridSize][agGridSize];
+    int m_gridX;
+    int m_gridY;
+    bool m_doAutoAntighosting;
+    bool m_doManualAntighosting;
+    QImage* m_patchesMask;
+    bool m_patchesEdited;
+
+	void setAntiGhostingWidget(QImage*, QPair<int, int>);
+    void cropAgMasks(const QRect& ca);
+    void computeAgMask();
 
-	QScrollArea *scrollArea;
-	PreviewWidget *previewWidget;
-	int additional_shift_value;
-	QList< QPair<int,int> > HV_offsets;
-	HistogramLDR *histogram;
-	QSize previousPreviewWidgetSize;
-	PanIconWidget *panIconWidget;
-	QToolButton *cornerButton;
-	SelectionTool *selectionTool;
-	bool m_MdrSaved;
-	LuminanceOptions luminanceOptions;
-	QVector<float> expotimes;
 private slots:
-	void slotPanIconSelectionMoved(QRect);
-	void slotPanIconHidden();
-	void slotCornerButtonPressed();
 	void saveImagesButtonClicked();
 	void updatePivot(int);
 	void updateMovable(int);
@@ -88,18 +103,28 @@ private slots:
 	void enterWhatsThis();
 	void zoomIn();
 	void zoomOut();
-	void fitPreview(bool);
+	void fitPreview();
+	void fillPreview();
 	void origSize();
-	void crop_stack();
+	void cropStack();
 	void nextClicked();
 	void maskColorButtonClicked();
+	void lassoColorButtonClicked();
 	void antighostToolButtonToggled(bool);
 	void blendModeCBIndexChanged(int);
 	void setupConnections();
-	void updateScrollBars(QPoint diff);
 	void restoreSaveImagesButtonState();
+    void addGoodImage();
+    void removeGoodImage();
+    void updateAgMask(int);
+    void antighostToolButtonPaintToggled(bool);
+    void saveAgMask();
+    void applySavedAgMask();
+    void on_recomputePatches_pushButton_clicked();
+    void on_autoAG_checkBox_toggled(bool toggled);
+    void updateThresholdSlider(int newValue);
+    void updateThresholdSpinBox(double newThreshold);
+    void setPatchesEdited();
 };
 
-
-
 #endif
