@@ -31,6 +31,7 @@ for which a new license (GPL+exception) is in place.
 #include "ui_HelpSideBar.h"
 
 #include <QAction>
+#include <QBuffer>
 #include <QDir>
 #include <QDomDocument>
 #include <QEvent>
@@ -55,6 +56,8 @@ for which a new license (GPL+exception) is in place.
 #include <QXmlDefaultHandler>
 #include <QDesktopServices>
 
+#include <QDebug>
+
 #include "Common/global.h"
 #include "HelpBrowser/schelptreemodel.h"
 #include "HelpBrowser/LuminancePaths.h"
@@ -159,7 +162,10 @@ HelpBrowser::HelpBrowser( QWidget* parent, const QString& /*caption*/, const QSt
     connect(m_Ui->textBrowser->page(), SIGNAL(linkHovered(const QString &, const QString &, const QString & )), this, SLOT(linkHovered(const QString &, const QString &, const QString & )));
 
 	language = guiLanguage.isEmpty() ? QString("en") : guiLanguage.left(2);
-	finalBaseDir = LuminancePaths::HelpDir();
+   	finalBaseDir = LuminancePaths::HelpDir();
+
+    qDebug() << finalBaseDir;
+
     m_Ui->textBrowser->setHome( QUrl::fromLocalFile( finalBaseDir + "index.html" ));
 	menuModel=NULL;
     loadMenu();
@@ -167,7 +173,6 @@ HelpBrowser::HelpBrowser( QWidget* parent, const QString& /*caption*/, const QSt
     if (menuModel!=NULL)
 	{
 		readBookmarks();
-		readHistory();
 		jumpToHelpSection(jumpToSection, jumpToFile );
 		languageChange();
 	}
@@ -190,39 +195,42 @@ void HelpBrowser::closeEvent(QCloseEvent *)
 
 	// no need to delete child widgets, Qt does it all for us
 	// bookmarks
-	QFile bookFile(bookmarkFile());
-	if (bookFile.open(QIODevice::WriteOnly))
-	{
-		QTextStream stream(&bookFile);
-		stream.setCodec("UTF-8");
-		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
-		stream << "<bookmarks>\n";
+    LuminanceOptions options;
+    {
+        QByteArray ba;
+	    QTextStream stream(&ba);
+	    stream.setCodec("UTF-8");
+	    stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+	    stream << "<bookmarks>\n";
         QTreeWidgetItemIterator it(helpSideBar->m_Ui->bookmarksView);
-		while (*it) 
-		{
-			if (bookmarkIndex.contains((*it)->text(0)))
-			{
-				QString pagetitle(bookmarkIndex.value((*it)->text(0)).first);
-				QString filename(bookmarkIndex.value((*it)->text(0)).second);
-				stream << "\t<item title=\"" << (*it)->text(0) << "\" pagetitle=\"" << pagetitle << "\" url=\"" << filename << "\" />\n";
-			}
-			++it;
-		}
-		stream << "</bookmarks>\n";
-		bookFile.close();
-	}
-	// history
-  	QFile histFile(historyFile());
-	if (histFile.open(QIODevice::WriteOnly))
+	    while (*it) 
+	    {
+		    if (bookmarkIndex.contains((*it)->text(0)))
+		    {
+			    QString pagetitle(bookmarkIndex.value((*it)->text(0)).first);
+			    QString filename(bookmarkIndex.value((*it)->text(0)).second);
+			    stream << "\t<item title=\"" << (*it)->text(0) << "\" pagetitle=\"" << pagetitle << "\" url=\"" << filename << "\" />\n";
+		    }
+		    ++it;
+	    }
+	    stream << "</bookmarks>\n";
+        stream.flush();
+
+        options.setValue(KEY_HELP_BOOKMARK, ba);
+    }
+
+    // history
 	{
-		QTextStream stream(&histFile);
+        QByteArray ba;
+		QTextStream stream(&ba);
 		stream.setCodec("UTF-8");
 		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 		stream << "<history>\n";
 		for (QMap<QAction*,histd2>::Iterator it = mHistory.begin() ; it != mHistory.end(); ++it)
 			stream << "\t<item title=\"" << it.value().title << "\" url=\"" << it.value().url << "\" />\n";
 		stream << "</history>\n";
-		histFile.close();
+        stream.flush();
+        options.setValue(KEY_HELP_HISTORY, ba);
 	}
 	// size
 // 	prefs->set("xsize", width());
@@ -368,7 +376,7 @@ void HelpBrowser::searchingButton_clicked()
 
 void HelpBrowser::searchingInDirectory(const QString& aDir)
 {
-	QDir dir(QDir::convertSeparators(aDir + "/"));
+	QDir dir(QDir::toNativeSeparators(aDir + "/"));
 	QStringList in;
 	in.append("*.html");
 	QStringList lst = dir.entryList(in);
@@ -402,7 +410,7 @@ void HelpBrowser::searchingInDirectory(const QString& aDir)
 	QStringList dst = dir.entryList(in, QDir::Dirs);
 	for (QStringList::Iterator it = dst.begin(); it != dst.end(); ++it)
 		if ((*it)!="." && (*it)!="..")
-			searchingInDirectory(QDir::convertSeparators(aDir + QString((*it)) + "/"));
+			searchingInDirectory(QDir::toNativeSeparators(aDir + QString((*it)) + "/"));
 }
 
 void HelpBrowser::find()
@@ -444,10 +452,11 @@ void HelpBrowser::bookmarkButton_clicked()
  	if (title.isNull())
  		return;
 	//TODO: start storing full paths
- 	QString toFind(fname.remove(QDir::convertSeparators(finalBaseDir)));
+ 	QString toFind(fname.remove(finalBaseDir));
 	toFind=toFind.mid(1, toFind.length()-1);
 	QMapIterator<QString, QString> i(quickHelpIndex);
-	while (i.hasNext())
+
+    while (i.hasNext())
 	{
 		i.next();
 		if (i.value()==toFind)
@@ -524,7 +533,7 @@ void HelpBrowser::loadHelp(const QString& filename)
 			toLoad=filename;
 		else
 		{
-			toLoad = LuminancePaths::HelpDir() +"index.html";
+   			toLoad = LuminancePaths::HelpDir() + "index.html";
  			language="en";
             //qDebug("Help index: %c", toLoad);
 			fi = QFileInfo(toLoad);
@@ -557,14 +566,14 @@ void HelpBrowser::loadHelp(const QString& filename)
 
 void HelpBrowser::loadMenu()
 {
-	QString baseHelpDir = LuminancePaths::HelpDir();
+    QString baseHelpDir(LuminancePaths::HelpDir());
 	QString baseHelpMenuFile = baseHelpDir + "menu.xml";
 	QFileInfo baseFi = QFileInfo(baseHelpMenuFile);
 	QString toLoad = baseHelpMenuFile;
 	finalBaseDir=baseFi.path();
-        if (baseFi.exists())
+    if (baseFi.exists())
 	{
-                if (menuModel!=NULL)
+        if (menuModel!=NULL)
 			delete menuModel;
 		menuModel=new ScHelpTreeModel(toLoad, "Topic", "Location", &quickHelpIndex);
 	
@@ -585,28 +594,19 @@ void HelpBrowser::loadMenu()
 
 void HelpBrowser::readBookmarks()
 {
+    LuminanceOptions options;
+    QByteArray ba(options.value(KEY_HELP_BOOKMARK).toByteArray());
+    QBuffer buffer(&ba);
 	BookmarkParser2 handler;
     handler.view = helpSideBar->m_Ui->bookmarksView;
 	handler.quickHelpIndex=&quickHelpIndex;
 	handler.bookmarkIndex=&bookmarkIndex;
-	QFile xmlFile(bookmarkFile());
-	QXmlInputSource source(&xmlFile);
+	QXmlInputSource source(&buffer);
 	QXmlSimpleReader reader;
 	reader.setContentHandler(&handler);
 	reader.parse(source);
 }
 
-void HelpBrowser::readHistory()
-{
- 	HistoryParser2 handler;
- 	handler.helpBrowser = this;
- 	QFile xmlFile(historyFile());
- 	QXmlInputSource source(&xmlFile);
- 	QXmlSimpleReader reader;
- 	reader.setContentHandler(&handler);
- 	reader.parse(source);
-}
-
 void HelpBrowser::setText(const QString& str)
 {
     m_Ui->textBrowser->setHtml(str);
@@ -663,57 +663,6 @@ void HelpBrowser::itemBookmarkSelected(QTreeWidgetItem *twi, int i)
 	}
 }
 
-/*! \brief Returns the name of the cfg file for bookmarks.
-A helper function.
-\author Petr Vanek <petr@yarpen.cz>
-*/
-QString HelpBrowser::bookmarkFile()
-{
-	//TODO   MAC OSX
-	//QString appDataDir(typotek::getInstance()->getOwnDir().path() + "/");
-	QString sep(QDir::separator());
-#ifdef Q_WS_MAC	
-	QString appDataDir(QDir::homePath() + sep + "Library" + sep + "LuminanceHDR" + sep);
-#elif WIN32
-	QString appDataDir(QDir::homePath() + sep + "LuminanceHDR" + sep);
-#else
-	QString appDataDir(QDir::homePath() + sep + ".LuminanceHDR" + sep);
-#endif
-	QString fname(appDataDir + "HelpBookmarks.xml");
-// 	if (!QFile::exists(fname))
-// 	{
-// 		QDir d(QDir::convertSeparators(appDataDir));
-// 		d.mkdir("doc");
-// 	}
-	return fname;
-}
-
-
-/*! \brief Returns the name of the cfg file for persistent history.
-A helper function.
-\author Petr Vanek <petr@yarpen.cz>
-*/
-QString HelpBrowser::historyFile()
-{
-	//QString appDataDir(typotek::getInstance()->getOwnDir().path() + "/");
-	QString sep(QDir::separator());
-#ifdef Q_WS_MAC	
-	QString appDataDir(QDir::homePath() + sep + "Library" + sep + "LuminanceHDR" + sep);
-#elif WIN32
-	QString appDataDir(QDir::homePath() + sep + "LuminanceHDR" + sep);
-#else
-	QString appDataDir(QDir::homePath() + sep + ".LuminanceHDR" + sep);
-	//QString fname(appDataDir + "HelpHistory.xml");
-#endif	
-	QString fname(appDataDir + "HelpHistory.xml");
-// 	if (!QFile::exists(fname))
-// 	{
-// 		QDir d(QDir::convertSeparators(appDataDir));
-// 		d.mkdir("doc");
-// 	}
-	return fname;
-}
-
 void HelpBrowser::displayNoHelp()
 {
 	QString noHelpMsg=tr("<h2><p>Sorry, no manual is installed!</p><p>Please contact your package provider or LuminanceHDR team if you built the application yourself</p></h2>", "HTML message for no documentation available to show");
