@@ -39,11 +39,12 @@
 
 #include "Core/IOWorker.h"
 #include "Core/TMWorker.h"
-#include "TonemappingEngine/TonemapOperator.h"
+
+#include "Libpfs/tm/TonemapOperator.h"
 
 #if defined(_MSC_VER)
-	#include <fcntl.h>
-	#include <io.h>
+#include <fcntl.h>
+#include <io.h>
 #endif
 
 namespace
@@ -147,6 +148,8 @@ static struct option cmdLineOptions[] = {
     { "tmoptions", required_argument, NULL, 'p' },
     { "output", required_argument, NULL, 'o' },
     { "quality", required_argument, NULL, 'q' },
+    { "savealigned", required_argument, NULL, 'd' },
+    { "autoag", required_argument, NULL, 'b' },
     { NULL, 0, NULL, 0 }
 };
 
@@ -157,7 +160,10 @@ CommandLineInterfaceManager::CommandLineInterfaceManager(const int argc, char **
     alignMode(NO_ALIGN),
     tmopts(TMOptionsOperations::getDefaultTMOptions()),
     verbose(false),
-	quality(100)
+	quality(100),
+    threshold(0.5f),
+    doAutoAntighosting(false),
+    saveAlignedImagesPrefix("")
 {
     hdrcreationconfig.weights = TRIANGULAR;
     hdrcreationconfig.response_curve = LINEAR;
@@ -177,7 +183,7 @@ void CommandLineInterfaceManager::parseArgs()
 //        cliOptions += cmdLineOptions[i].val;
 //    }
 
-    while( (c = getopt_long_only (argc, argv, ":hva:e:c:l:s:g:r:t:p:o:u:q:", cmdLineOptions, &optionIndex)) != -1 )
+    while( (c = getopt_long_only (argc, argv, ":hva:e:c:l:s:g:r:t:p:o:u:q:d:b:", cmdLineOptions, &optionIndex)) != -1 )
     {
         switch ( c )
         {
@@ -411,6 +417,15 @@ void CommandLineInterfaceManager::parseArgs()
 			if (quality < 0 || quality > 100)
             	printErrorAndExit(tr("Error: Quality must be in the range [0-100]."));
             break;
+        case 'd':
+            saveAlignedImagesPrefix = QString(optarg);
+            break;
+        case 'b':
+            threshold = QString(optarg).toFloat();
+			if (threshold < 0.0f ||  threshold > 1.0f)
+            	printErrorAndExit(tr("Error: Threshold must be in the range [0-1]."));
+            doAutoAntighosting = true;
+            break;
         case '?':
             printErrorAndExit(tr("Error: Unknown option %1.").arg(optopt));
         case ':':
@@ -463,19 +478,15 @@ void CommandLineInterfaceManager::execCommandLineParamsSlot()
             printIfVerbose(QObject::tr("Temporary directory: %1").arg(luminance_options.getTempDir()), verbose);
             printIfVerbose(QObject::tr("Using %1 threads.").arg(luminance_options.getNumThreads()), verbose);
         }
-
         hdrCreationManager.reset( new HdrCreationManager(true) );
-        connect(hdrCreationManager.data(), SIGNAL(finishedLoadingInputFiles(QStringList)), this, SLOT(finishedLoadingInputFiles(QStringList)));
+        connect(hdrCreationManager.data(), SIGNAL(finishedLoadingFiles()), this, SLOT(finishedLoadingInputFiles()));
         connect(hdrCreationManager.data(), SIGNAL(finishedAligning(int)), this, SLOT(createHDR(int)));
         connect(hdrCreationManager.data(), SIGNAL(ais_failed(QProcess::ProcessError)), this, SLOT(ais_failed(QProcess::ProcessError)));
 		connect(hdrCreationManager.data(), SIGNAL(errorWhileLoading(QString)),this, SLOT(errorWhileLoading(QString)));
-		//connect(hdrCreationManager.data(), SIGNAL(maximumValue(int)),this, SLOT(setProgressBar(int)));
-		//connect(hdrCreationManager.data(), SIGNAL(nextstep(int)),this, SLOT(updateProgressBar(int)));
 		connect(hdrCreationManager.data(), SIGNAL(aisDataReady(QByteArray)),this, SLOT(readData(QByteArray)));
 			
         hdrCreationManager->setConfig(hdrcreationconfig);
-        hdrCreationManager->setFileList(inputFiles);
-        hdrCreationManager->loadInputFiles();
+        hdrCreationManager->loadFiles(inputFiles);
     }
     else
     {
@@ -495,20 +506,21 @@ void CommandLineInterfaceManager::execCommandLineParamsSlot()
     }
 }
 
-void CommandLineInterfaceManager::finishedLoadingInputFiles(QStringList filesLackingExif)
+void CommandLineInterfaceManager::finishedLoadingInputFiles()
 {
-    if (filesLackingExif.size()!=0 && ev.isEmpty())
+    QStringList filesLackingExif = hdrCreationManager->getFilesWithoutExif();
+    if (filesLackingExif.size() !=0 && ev.isEmpty())
     {
         printErrorAndExit(tr("Error: Exif data missing in images and EV values not specified on the commandline, bailing out."));
     }
     if (!ev.isEmpty())
     {
-        for (int i=0; i < ev.size(); i++)
-            hdrCreationManager->setEV(ev.at(i),i);
+        for (int i = 0; i < ev.size(); i++)
+            hdrCreationManager->getFile(i).setEV(ev.at(i));
 
         printIfVerbose( tr("EV values have been assigned.") , verbose);
     }
-    hdrCreationManager->checkEVvalues();
+    //hdrCreationManager->checkEVvalues();
     if (alignMode == AIS_ALIGN)
     {
         hdrCreationManager->align_with_ais();
@@ -532,11 +544,30 @@ void CommandLineInterfaceManager::createHDR(int errorcode)
 {
 	if (errorcode != 0)
 		printIfVerbose( tr("Failed aligning images.") , verbose);
-    hdrCreationManager->removeTempFiles();
 
     printIfVerbose( tr("Creating (in memory) the HDR.") , verbose);
+    
+    if (errorcode == 0 && alignMode != NO_ALIGN && saveAlignedImagesPrefix != "") {
+        hdrCreationManager->saveImages(saveAlignedImagesPrefix);
+    }
 
-    HDR.reset( hdrCreationManager->createHdr(false,1) );
+    hdrCreationManager->removeTempFiles();
+    if (doAutoAntighosting) {
+        QList<QPair<int, int> > dummyOffset;
+        QStringList::ConstIterator it = inputFiles.begin();
+        while( it != inputFiles.end() ) {
+            dummyOffset.append(qMakePair(0,0));
+            ++it;
+        }
+        ProgressHelper ph;
+        bool patches[agGridSize][agGridSize];
+        float patchesPercent;
+        int h0 = hdrCreationManager->computePatches(threshold, patches, patchesPercent, dummyOffset);
+        HDR.reset( hdrCreationManager->doAntiGhosting(patches, h0, false, &ph) ); // false means auto anti-ghosting
+    }
+    else {
+        HDR.reset( hdrCreationManager->createHdr(false,1) );
+    }
     saveHDR();
 }
 
@@ -587,8 +618,18 @@ void  CommandLineInterfaceManager::startTonemap()
         // The scoped pointer will free the memory automatically later on
         QScopedPointer<pfs::Frame> tm_frame( tm_worker.computeTonemap(HDR.data(), tmopts.data()) );
 
+        QString inputfname; // to copy EXIF tags from 1st input image to saved LDR
+        if (inputFiles.isEmpty())
+            inputfname = "";
+        else
+            inputfname = inputFiles.first();
+
         // Create an ad-hoc IOWorker to save the file
-        if ( IOWorker().write_ldr_frame(tm_frame.data(), saveLdrFilename, quality, tmopts.data()) )
+        if ( IOWorker().write_ldr_frame(tm_frame.data(), saveLdrFilename,
+                                        inputfname,
+                                        hdrCreationManager.data() ? hdrCreationManager->getExpotimes(): QVector<float>(),
+                                        tmopts.data(),
+                                        pfs::Params("quality", (size_t)quality) ) )
         {
             // File save successful
             printIfVerbose( tr("Image %1 saved successfully").arg(saveLdrFilename) , verbose);
@@ -617,21 +658,22 @@ void CommandLineInterfaceManager::printHelp(char * progname)
     QString help=
             tr("Usage: %1 [OPTIONS]... [INPUTFILES]...").arg(progname) + "\n" +
             "\t" + tr("Commandline interface to %1.").arg(progname) + "\n\n" +
-            "\t" + tr("-h --help              Display this help.") + "\n" +
-            "\t" + tr("-v --verbose           Print more messages during execution.") + "\n" +
-            "\t" + tr("-a --align AIS|MTB     Align Engine to use during HDR creation (default: no alignment).") + "\n" +
-            "\t" + tr("-e --ev EV1,EV2,...    Specify numerical EV values (as many as INPUTFILES).") + "\n" +
-            "\t" + tr("-c --config            HDR creation config. Possible values: ") + "\n" +
+            "\t" + tr("-h --help               Display this help.") + "\n" +
+            "\t" + tr("-v --verbose            Print more messages during execution.") + "\n" +
+            "\t" + tr("-a --align AIS|MTB      Align Engine to use during HDR creation (default: no alignment).") + "\n" +
+            "\t" + tr("-d --savealigned prefix Save aligned images to files which names start with prefix") + "\n" +
+            "\t" + tr("-e --ev EV1,EV2,...     Specify numerical EV values (as many as INPUTFILES).") + "\n" +
+            "\t" + tr("-c --config             HDR creation config. Possible values: ") + "\n" +
             "\t\t" + tr("weight=triangular|gaussian|plateau:response_curve=from_file|linear|gamma|log|robertson:model=robertson|debevec:curve_filename=your_file_here.m") + "\n" +
             "\t\t" + tr("(Default is weight=triangular:response_curve=linear:model=debevec) ") + "\n" +
-            "\t" + tr("-l --load HDR_FILE     Load an HDR instead of creating a new one. ") + "\n" +
-            "\t" + tr("-s --save HDR_FILE     Save to a HDR file format. (default: don't save) ") + "\n" +
-            "\t" + tr("-g --gamma VALUE       Gamma value to use during tone mapping. (default: 1) ") + "\n" +
-            "\t" + tr("-r --resize VALUE      Width you want to resize your HDR to (resized before gamma and tone mapping) ") + "\n" +
-            "\t" + tr("-t --tmo               Tone mapping operator. Legal values are: ") + "\n" +
+            "\t" + tr("-l --load HDR_FILE      Load an HDR instead of creating a new one. ") + "\n" +
+            "\t" + tr("-s --save HDR_FILE      Save to a HDR file format. (default: don't save) ") + "\n" +
+            "\t" + tr("-g --gamma VALUE        Gamma value to use during tone mapping. (default: 1) ") + "\n" +
+            "\t" + tr("-r --resize VALUE       Width you want to resize your HDR to (resized before gamma and tone mapping) ") + "\n" +
+            "\t" + tr("-t --tmo                Tone mapping operator. Legal values are: ") + "\n" +
             "\t\t" + tr("ashikhmin|drago|durand|fattal|pattanaik|reinhard02|reinhard05|mantiuk06|mantiuk08") + "\n" +
             "\t\t" + tr("(Default is mantiuk06)") + "\n" +
-            "\t" + tr("-p --tmoptions         Tone mapping operator options. Legal values are: ") + "\n" +
+            "\t" + tr("-p --tmoptions          Tone mapping operator options. Legal values are: ") + "\n" +
             "\t\t" + tr("alpha=VALUE:beta=VALUE:color=VALUE:noise=VALUE:new=true|false (for fattal)") + "\n" +
             "\t\t" + tr("contrast=VALUE:saturation=VALUE:detail=VALUE:equalization=true|false (for mantiuk06)") + "\n" +
             "\t\t" + tr("colorsaturation=VALUE:contrastenhancement=VALUE:luminancelevel=VALUE:setluminance=true|false (for mantiuk08)") + "\n" +
@@ -642,9 +684,10 @@ void CommandLineInterfaceManager::printHelp(char * progname)
             "\t\t" + tr("scales=true|false:key=VALUE:phi=VALUE:num=VALUE:low=VALUE:high=VALUE (for reinhard02)") + "\n" +
             "\t\t" + tr("brightness=VALUE:chroma=VALUE:lightness=VALUE (for reinhard05)") + "\n" +
             "\t\t" + tr("(default is contrast=0.3:equalization=false:saturation=1.8, see also -o)") + "\n" +
-            "\t" + tr("-o --output LDR_FILE   File name you want to save your tone mapped LDR to.") + "\n" +
-            "\t" + tr("-q --quality VALUE   Quality of the saved tone mapped file (0-100).") + "\n" +
-            "\t" + tr("                       (No tonemapping is performed unless -o is specified).") + "\n\n" +
+            "\t" + tr("-o --output LDR_FILE    File name you want to save your tone mapped LDR to.") + "\n" +
+            "\t" + tr("-q --quality VALUE      Quality of the saved tone mapped file (0-100).") + "\n" +
+            "\t" + tr("-b --autoag THRESHOLD   Enable auto anti-ghosting with given threshold.") + "\n" +
+            "\t" + tr("                        (No tonemapping is performed unless -o is specified).") + "\n\n" +
             tr("You must either load an existing HDR file (via the -l option) or specify INPUTFILES to create a new HDR.\n");
     printErrorAndExit(help);
 }
