@@ -23,13 +23,21 @@
 
 #include <QCoreApplication>
 
+#include "Common/config.h"
+#include "Common/LuminanceOptions.h"
+#include "Common/TranslatorManager.h"
+
 #include "MainCli/commandline.h"
-#include "Common/global.h"
+
 
 int main( int argc, char ** argv )
 {
+    QCoreApplication::setApplicationName(LUMINANCEAPPLICATION);
+    QCoreApplication::setOrganizationName(LUMINANCEORGANIZATION);
     QCoreApplication application( argc, argv );
-    installTranslators(false);
+    LuminanceOptions lumOpts;
+
+    TranslatorManager::setLanguage( lumOpts.getGuiLang(), false );
 
     CommandLineInterfaceManager cli( argc, argv );
 
