@@ -2,6 +2,7 @@
  * This file is a part of Luminance HDR package.
  * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007 Giuseppe Rota
+ * Copyright (C) 2012 Davide Anastasia
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
  * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
+ * @author Davide Anastasia <davideanastasia@users.sourceforge.net>
  */
 
 #include <QApplication>
@@ -29,35 +31,33 @@
 #include <QStringList>
 
 #include "Common/global.h"
+#include "Common/config.h"
+#include "Common/TranslatorManager.h"
 #include "MainWindow/MainWindow.h"
 
-#ifdef WIN32
-#include <QMessageBox>
-#include <windows.h>
-#endif
-
 namespace
 {
 QStringList getCliFiles(const QStringList& arguments)
 {
-    QStringList return_value;   // empty QStringList;
+    // empty QStringList;
+    QStringList fileList;
 
     // check if any of the parameters is a proper file on the file system
     // I skip the first value of the list because it is the name of the executable
-    for (int i = 1; i < arguments.size(); ++i)
-    {
+    for (int i = 1; i < arguments.size(); ++i) {
         QFile file( arguments.at(i).toLocal8Bit() );
 
-        if ( file.exists() ) return_value.push_back( arguments.at(i).toLocal8Bit() );
+        if ( file.exists() ) {
+            fileList.push_back( arguments.at(i).toLocal8Bit() );
+        }
     }
 
-    return return_value;
+    return fileList;
 }
 }
 
-
 #ifdef WIN32
-inline void customMessageHandler(QtMsgType type, const char *msg)
+void customMessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
 	QString txt;
 	switch (type) {
@@ -76,9 +76,11 @@ inline void customMessageHandler(QtMsgType type, const char *msg)
 	}
 
 	QFile outFile("debuglog.txt");
-	outFile.open(QIODevice::WriteOnly | QIODevice::Append);
-	QTextStream ts(&outFile);
-	ts << txt << endl;
+	if (outFile.open(QIODevice::WriteOnly | QIODevice::Append))
+	{
+        QTextStream ts(&outFile);
+        ts << txt << endl;
+	}
 }
 #endif
 
@@ -88,31 +90,29 @@ int main( int argc, char ** argv )
     QApplication application( argc, argv );
 
 #ifdef WIN32
-    //qInstallMsgHandler(customMessageHandler);
-
-    bool found_DLL = false;
-    foreach (QString path, application.libraryPaths())
-    {
-        if ( QFile::exists(path+"/imageformats/qjpeg4.dll") )
-        {
-            found_DLL = true;
-        }
-    }
-    if (!found_DLL)
-    {
-        QMessageBox::critical(NULL,
-                              QObject::tr("Aborting..."),
-                              QObject::tr("Cannot find Qt's JPEG Plugin...<br>Please unzip the DLL package with the option \"use folder names\" activated."));
-        return 1;
-    }
+    // qInstallMessageHandler(customMessageHandler);
 #endif
 
-    installTranslators(true);
-    MainWindow* MW = new MainWindow;
+    QCoreApplication::setApplicationName(LUMINANCEAPPLICATION);
+    QCoreApplication::setOrganizationName(LUMINANCEORGANIZATION);
 
-    MW->setInputFiles( getCliFiles( application.arguments() ) );
+    LuminanceOptions::isCurrentPortableMode =
+            QDir(QApplication::applicationDirPath()).exists("PortableMode.txt");
 
-    MW->show();
+    if (LuminanceOptions::isCurrentPortableMode)
+    {
+        QSettings::setDefaultFormat(QSettings::IniFormat);
+        QSettings::setPath(QSettings::IniFormat,
+                           QSettings::UserScope, QDir::currentPath());
+    }
+
+    LuminanceOptions::conditionallyDoUpgrade();
+    TranslatorManager::setLanguage( LuminanceOptions().getGuiLang() );
+
+    MainWindow* mainWindow = new MainWindow;
+
+    mainWindow->show();
+    mainWindow->openFiles( getCliFiles( application.arguments() ) );
 
     return application.exec();
 }
