@@ -1,8 +1,8 @@
 /**
  * This file is a part of Luminance HDR package.
  * ----------------------------------------------------------------------
- * Copyright (C) 2006,2007 Giuseppe Rota
- * Copyright (C) 2011 Davide Anastasia
+ * Copyright (C) 2006-2007 Giuseppe Rota
+ * Copyright (C) 2011-2012 Davide Anastasia
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@
  * Division of the Central Widget using QSplitter
  */
 
-#ifndef MAINGUI_IMPL_H
-#define MAINGUI_IMPL_H
+#ifndef MAINWINDOW_H
+#define MAINWINDOW_H
 
 #include <QMainWindow>
 #include <QString>
@@ -40,8 +40,12 @@
 #include <QSignalMapper>
 #include <QSplitter>
 #include <QTabWidget>
+#include <QDockWidget>
 #include <QThread>
 #include <QProgressBar>
+#include <QScrollArea>
+#include <QScopedPointer>
+#include <QFutureWatcher>
 
 #include "Common/LuminanceOptions.h"
 
@@ -65,6 +69,9 @@ class TonemappingPanel;     // #include "TonemappingPanel/TonemappingPanel.h"
 class TonemappingOptions;   // #include "Core/TonemappingOptions.h"
 class TMWorker;
 
+
+class UpdateChecker;        // #include "MainWindow/UpdateChecker.h"
+
 class MainWindow: public QMainWindow
 {
     Q_OBJECT
@@ -72,32 +79,37 @@ class MainWindow: public QMainWindow
 public:
     MainWindow(QWidget *parent = 0);
     // Constructor loading file inside
-    MainWindow(pfs::Frame* curr_frame, QString new_fname, bool needSaving = false, QWidget *parent = 0);
+    MainWindow(pfs::Frame* curr_frame, const QString& new_fname,
+        const QStringList& inputFileNames, bool needSaving = false, QWidget *parent = 0);
     ~MainWindow();
 
 public Q_SLOTS:
 
     // I/O
-    void save_hdr_success(GenericViewer* saved_hdr, QString fname);
+    void save_hdr_success(GenericViewer* saved_hdr, const QString& fname);
     void save_hdr_failed();
-    void save_ldr_success(GenericViewer* saved_ldr, QString fname);
+    void save_ldr_success(GenericViewer* saved_ldr, const QString& fname);
     void save_ldr_failed();
 
-    void load_failed(QString);
-    void load_success(pfs::Frame* new_hdr_frame, QString new_fname, bool needSaving = false);
+    void load_failed(const QString&);
+    void load_success(pfs::Frame* new_hdr_frame, const QString& new_fname,
+                      const QStringList& inputFileNames = QStringList(), bool needSaving = false);
 
     void ioBegin();
     void ioEnd();
 
     void setMainWindowModified(bool b);
 
-    void setInputFiles(const QStringList& files);
+    void openFile(const QString& file);
+    void openFiles(const QStringList& files);
 
 protected Q_SLOTS:
-    void on_fileNewAction_triggered();
-    void createNewHdr(QStringList files);
 
-    void on_fileOpenAction_triggered();    //for File->Open, it then calls loadFile()
+    void on_fileNewAction_triggered();
+    void createNewHdr(const QStringList& files);
+
+    //for File->Open, it then calls loadFile()
+    void on_fileOpenAction_triggered();
     void on_fileSaveAsAction_triggered();
     void on_fileSaveAllAction_triggered();
     void on_actionSave_Hdr_Preview_triggered();
@@ -133,14 +145,16 @@ protected Q_SLOTS:
     void on_Transplant_Exif_Data_action_triggered();
 
     void on_actionFix_Histogram_toggled(bool checked);
-
-    void openInputFiles();
+    void on_actionWhite_Balance_triggered();
+    void whiteBalanceDone();
 
     // Tool Bar Handling
     void Text_Under_Icons();
     void Icons_Only();
     void Text_Alongside_Icons();
     void Text_Only();
+    void showPreviewsOnTheRight();
+    void showPreviewsOnTheBottom();
 
     // Window Menu Display and Functionalities
     void updateWindowMenu();
@@ -164,13 +178,16 @@ protected Q_SLOTS:
     void splashShowDonationsPage();
     void splashClose();
 
+    void onUpdateAvailable();
+    void on_actionUpdateAvailable_triggered();
+
     // TM
     void tonemapBegin();
     void tonemapEnd();
     void tonemapImage(TonemappingOptions *opts);
     void addLdrFrame(pfs::Frame*, TonemappingOptions*);
     //void addLDRResult(QImage*, quint16*);
-    void tonemapFailed(QString);
+    void tonemapFailed(const QString&);
 
     // lock functionalities
     void on_actionLock_toggled(bool);
@@ -186,16 +203,20 @@ protected Q_SLOTS:
 	void on_actionGamut_Check_toggled(bool);
 	void updateSoftProofing(int);
 
+    void on_actionFits_Importer_triggered();
+
 Q_SIGNALS:
     // update HDR
     void updatedHDR(pfs::Frame*);
 
 protected:
     QSplitter *m_centralwidget_splitter;
+    QSplitter *m_bottom_splitter;
+
     QTabWidget *m_tabwidget;
 
     QSignalMapper *windowMapper;
-    LuminanceOptions luminance_options;
+    LuminanceOptions *luminance_options;
     QDialog *splash;
 
     // Recent Files Management
@@ -206,14 +227,22 @@ protected:
     QList<QAction*> openMainWindows;
 
     HelpBrowser* helpBrowser;
-    QStringList inputFiles;
 
+    //! \brief contains the file names of the images loaded by the wizard,
+    //! they are used to copy EXIF tags to saved LDR images
+    QStringList m_inputFilesName;
+    //! \brief this contains the exposure times of the images to write to LDR
+    //! as EXIF comment
+    QVector<float> m_inputExpoTimes;
+
+    //! \group Event handler
     virtual void dragEnterEvent(QDragEnterEvent *);
     virtual void dropEvent(QDropEvent *);
-	virtual void changeEvent(QEvent* event);
-
-    void closeEvent(QCloseEvent *);
-
+    virtual void changeEvent(QEvent* event);
+    virtual void closeEvent(QCloseEvent *);
+	virtual bool event(QEvent * event);
+    //!
+	
     void dispatchrotate(bool clockwise);
 
     void updateRecentFileActions();
@@ -246,31 +275,34 @@ protected:
     bool maybeSave();
 
     // Preview Panel
-    PreviewPanel *previewPanel;
-
-    void openFiles(const QStringList& files);
-
-	#ifdef Q_WS_WIN
-		bool winEvent(MSG * message, long * result);
-	#endif
+    QScrollArea *m_PreviewscrollArea;
+    PreviewPanel *m_PreviewPanel;
 
 private:
-    static int sm_NumMainWindows;
+    // UI declaration
+    Ui::MainWindow* m_Ui;
+
+    // Tone Mapping Panel
+    TonemappingPanel *m_tonemapPanel;
 
     // I/O
     QThread *m_IOThread;
     IOWorker *m_IOWorker;
     QProgressBar* m_ProgressBar;
 
-    // UI declaration
-    Ui::MainWindow* m_Ui;
-
     // TM thread
     QThread* m_TMThread;
     TMWorker* m_TMWorker;
     TMOProgressIndicator* m_TMProgressBar;
-    // Tone Mapping Panel
-    TonemappingPanel *tmPanel;
+
+
+    QFutureWatcher<void> m_futureWatcher;
+    GenericViewer *m_viewerToProcess;
+    bool m_processingAWB;
+    int m_firstWindow;
+    
+    static int sm_NumMainWindows;
+    static QScopedPointer<UpdateChecker> sm_updateChecker;
 };
 
-#endif
+#endif // MAINWINDOW_H
