@@ -28,6 +28,7 @@
 #include <QFileDialog>
 #include <QWhatsThis>
 #include <QMessageBox>
+#include <QDebug>
 
 #include <iostream>
 #include <cmath>
@@ -35,6 +36,7 @@
 #include "Common/global.h"
 #include "Common/config.h"
 #include "Common/LuminanceOptions.h"
+#include "Common/TranslatorManager.h"
 #include "Preferences/PreferencesDialog.h"
 
 // UI
@@ -130,24 +132,6 @@ QStringList sanitizeAISparams(const QString& input_parameter_string)
     return temp_ais_options;
 }
 
-int mappingBatchTmQStringToInt(const QString& string)
-{
-    if (string == "JPEG")
-        return 0;
-    else if (string == "PNG")
-        return 1;
-    else if (string == "PPM")
-        return 2;
-    else if (string == "PBM")
-        return 3;
-    else if (string == "BMP")
-        return 4;
-    else if (string == "TIFF")
-        return 5;
-    return 0;   // I assume JPEG... at least it doesn't crash! :|
-}
-
-
 }
 
 PreferencesDialog::PreferencesDialog(QWidget *p):
@@ -156,45 +140,59 @@ PreferencesDialog::PreferencesDialog(QWidget *p):
 {
     m_Ui->setupUi(this);
 
-	fromIso639ToGuiIndex["cs"]=0;
-	fromIso639ToGuiIndex["zh"]=1;
-	fromIso639ToGuiIndex["en"]=2;
-	fromIso639ToGuiIndex["fi"]=3;
-	fromIso639ToGuiIndex["fr"]=4;
-	fromIso639ToGuiIndex["de"]=5;
-	fromIso639ToGuiIndex["hu"]=6;
-	fromIso639ToGuiIndex["id"]=7;
-	fromIso639ToGuiIndex["it"]=8;
-	fromIso639ToGuiIndex["pl"]=9;
-	fromIso639ToGuiIndex["ro"]=10;
-	fromIso639ToGuiIndex["ru"]=11;
-	fromIso639ToGuiIndex["es"]=12;
-	fromIso639ToGuiIndex["tr"]=13;
-	//fromIso639ToGuiIndex["hi"]=14;
-	//fromIso639ToGuiIndex["sk"]=15;
+#ifdef DEMOSAICING_GPL2
+	qDebug() << "PreferencesDialog: Found demosaicing pack GPL2";
+	m_Ui->user_qual_comboBox->addItem("DCB");
+	m_Ui->user_qual_comboBox->addItem("AHD v2");
+	m_Ui->user_qual_comboBox->addItem("AFD");
+	m_Ui->user_qual_comboBox->addItem("VCD");
+	m_Ui->user_qual_comboBox->addItem("VCD & AHD");
+	m_Ui->user_qual_comboBox->addItem("LMMSE");
+#endif
+#ifdef DEMOSAICING_GPL3
+	qDebug() << "PreferencesDialog: Found AMaZE";
+	m_Ui->user_qual_comboBox->addItem("AMaZE");
+#endif
 
-	fromGuiIndexToIso639[0]="cs";
-	fromGuiIndexToIso639[1]="zh";
-	fromGuiIndexToIso639[2]="en";
-	fromGuiIndexToIso639[3]="fi";
-	fromGuiIndexToIso639[4]="fr";
-	fromGuiIndexToIso639[5]="de";
-	fromGuiIndexToIso639[6]="hu";
-	fromGuiIndexToIso639[7]="id";
-	fromGuiIndexToIso639[8]="it";
-	fromGuiIndexToIso639[9]="pl";
-	fromGuiIndexToIso639[10]="ro";
+	fromIso639ToGuiIndex["cs"]= 0;
+    fromIso639ToGuiIndex["da"]= 1;
+	fromIso639ToGuiIndex["de"]= 2;
+	fromIso639ToGuiIndex["en"]= 3;
+	fromIso639ToGuiIndex["es"]= 4;
+	fromIso639ToGuiIndex["fr"]= 5;
+	fromIso639ToGuiIndex["id"]= 6;
+	fromIso639ToGuiIndex["it"]= 7;
+	fromIso639ToGuiIndex["hu"]= 8;
+	fromIso639ToGuiIndex["pl"]= 9;
+	fromIso639ToGuiIndex["pt_BR"]= 10;
+	fromIso639ToGuiIndex["ru"]=11;
+	fromIso639ToGuiIndex["ro"]=12;
+	fromIso639ToGuiIndex["fi"]=13;
+	fromIso639ToGuiIndex["tr"]=14;
+	fromIso639ToGuiIndex["zh"]=15;
+
+	fromGuiIndexToIso639[ 0]="cs";
+	fromGuiIndexToIso639[ 1]="da";
+	fromGuiIndexToIso639[ 2]="de";
+	fromGuiIndexToIso639[ 3]="en";
+	fromGuiIndexToIso639[ 4]="es";
+	fromGuiIndexToIso639[ 5]="fr";
+	fromGuiIndexToIso639[ 6]="id";
+	fromGuiIndexToIso639[ 7]="it";
+	fromGuiIndexToIso639[ 8]="hu";
+	fromGuiIndexToIso639[ 9]="pl";
+	fromGuiIndexToIso639[10]="pt_BR";
 	fromGuiIndexToIso639[11]="ru";
-	fromGuiIndexToIso639[12]="es";
-	fromGuiIndexToIso639[13]="tr";
-	//fromGuiIndexToIso639[14]="hi";
-	//fromGuiIndexToIso639[15]="sk";
+	fromGuiIndexToIso639[12]="ro";
+	fromGuiIndexToIso639[13]="fi";
+	fromGuiIndexToIso639[14]="tr";
+    fromGuiIndexToIso639[15]="zh";
 
     negcolor = LuminanceOptions().getViewerNegColor();
     infnancolor = LuminanceOptions().getViewerNanInfColor();
 
     from_options_to_gui(); //update the gui in order to show the options
-
+    
     toolButtonMapper = new QSignalMapper(this);
     connect(toolButtonMapper, SIGNAL(mapped(int)), this, SLOT(toolButton_clicked(int)));
 
@@ -232,12 +230,14 @@ void PreferencesDialog::on_ifnanColorButton_clicked()
 
 void PreferencesDialog::on_okButton_clicked()
 {
+    bool restartNeeded = false;
+
     LuminanceOptions luminance_options;
 
     if (luminance_options.getGuiLang() != fromGuiIndexToIso639[m_Ui->languageComboBox->currentIndex()])
     {
         luminance_options.setGuiLang( fromGuiIndexToIso639[m_Ui->languageComboBox->currentIndex()] );
-        installTranslators(true);
+        TranslatorManager::setLanguage( luminance_options.getGuiLang() );
     }
 
     // UI
@@ -247,10 +247,15 @@ void PreferencesDialog::on_okButton_clicked()
     luminance_options.setTempDir( m_Ui->lineEditTempPath->text() );
 
     luminance_options.setPreviewWidth( m_Ui->previewsWidthSpinBox->value() );
-    luminance_options.setShowFirstPageWizard( m_Ui->checkBoxWizardShowFirstPage->isChecked() );
+    luminance_options.setPreviewPanelActive( m_Ui->checkBoxTMOWindowsPreviewPanel->isChecked() );
+
+    if (m_Ui->chkPortableMode->isChecked() != LuminanceOptions::isCurrentPortableMode)
+    {
+        restartNeeded = true;
+        luminance_options.setPortableMode(m_Ui->chkPortableMode->isChecked());
+    }
 
     // --- Batch TM
-    luminance_options.setBatchTmLdrFormat( m_Ui->batchLdrFormatComboBox->currentText() );
     luminance_options.setBatchTmNumThreads( m_Ui->numThreadspinBox->value() );
 
     // --- Other Parameters
@@ -260,7 +265,26 @@ void PreferencesDialog::on_okButton_clicked()
     // --- RAW parameters
     luminance_options.setRawFourColorRGB( m_Ui->four_color_rgb_CB->isChecked() );
     luminance_options.setRawDoNotUseFujiRotate( m_Ui->do_not_use_fuji_rotate_CB->isChecked() );
-    luminance_options.setRawUserQuality( m_Ui->user_qual_comboBox->currentIndex() );
+	QString user_qual = m_Ui->user_qual_comboBox->itemText( m_Ui->user_qual_comboBox->currentIndex() );
+	if (user_qual == "Bilinear" ||
+		user_qual == "VNG" ||
+		user_qual == "PPG" ||
+		user_qual == "AHD") 
+			luminance_options.setRawUserQuality( m_Ui->user_qual_comboBox->currentIndex() );
+	else if(user_qual == "DCB")
+			luminance_options.setRawUserQuality( 4 );
+	else if(user_qual == "AHD v2")
+			luminance_options.setRawUserQuality( 5 );
+	else if(user_qual == "AFD")
+			luminance_options.setRawUserQuality( 6 );
+	else if(user_qual == "VCD")
+			luminance_options.setRawUserQuality( 7 );
+	else if(user_qual == "VCD & AHD")
+			luminance_options.setRawUserQuality( 8 );
+	else if(user_qual == "LMMSE")
+			luminance_options.setRawUserQuality( 9 );
+	else if(user_qual == "AMaZE")
+			luminance_options.setRawUserQuality( 10 );
     luminance_options.setRawMedPasses( m_Ui->med_passes_spinBox->value() );
     luminance_options.setRawWhiteBalanceMethod( m_Ui->wb_method_comboBox->currentIndex() );
     luminance_options.setRawTemperatureKelvin( m_Ui->TK_spinBox->value() );
@@ -272,7 +296,7 @@ void PreferencesDialog::on_okButton_clicked()
     luminance_options.setRawUseBlack( m_Ui->use_black_CB->isChecked() );
     luminance_options.setRawUseSaturation( m_Ui->use_sat_CB->isChecked() );
     luminance_options.setRawUseNoiseReduction( m_Ui->use_noise_CB->isChecked() );
-    luminance_options.setRawUseChroma( m_Ui->use_chroma_CB->isChecked() );
+    luminance_options.setRawUseChromaAber( m_Ui->use_chroma_CB->isChecked() );
     luminance_options.setRawNoiseReductionThreshold( m_Ui->threshold_spinBox->value() );
     luminance_options.setRawUserBlack( m_Ui->user_black_spinBox->value() );
     luminance_options.setRawUserSaturation( m_Ui->user_sat_spinBox->value() );
@@ -299,6 +323,10 @@ void PreferencesDialog::on_okButton_clicked()
     luminance_options.setValue(KEY_BLUE_TOOLBUTTON, m_Ui->blue_toolButton->isEnabled());
     luminance_options.setValue(KEY_GREEN_TOOLBUTTON, m_Ui->green_toolButton->isEnabled());
 
+    if (restartNeeded)
+    {
+        QMessageBox::information(this, tr("Restart"), tr("For the settings to take effect, please restart the application!"));
+    }
     accept();
 }
 
@@ -589,9 +617,6 @@ void PreferencesDialog::from_options_to_gui()
     // Temp directory
     m_Ui->lineEditTempPath->setText(luminance_options.getTempDir());
 
-    // Batch TM output format
-    int current_batch_tm_output_type = mappingBatchTmQStringToInt( luminance_options.getBatchTmLdrFormat() );
-    m_Ui->batchLdrFormatComboBox->setCurrentIndex( current_batch_tm_output_type );
 
     m_Ui->numThreadspinBox->setValue( luminance_options.getBatchTmNumThreads() );
 
@@ -605,11 +630,38 @@ void PreferencesDialog::from_options_to_gui()
     m_Ui->previewsWidthSpinBox->setValue( luminance_options.getPreviewWidth() );
 
     m_Ui->checkBoxTMOWindowsPreviewPanel->setChecked(luminance_options.isPreviewPanelActive());
-    m_Ui->checkBoxWizardShowFirstPage->setChecked(luminance_options.isShowFirstPageWizard());
+
+    m_Ui->chkPortableMode->setChecked(LuminanceOptions::isCurrentPortableMode);
+
+    QFile file(QDir(QApplication::applicationDirPath()).filePath(".write"));
+    bool dirWritable = file.open(QIODevice::ReadWrite);
+    if (dirWritable)
+        file.remove();
+    m_Ui->chkPortableMode->setEnabled(dirWritable);
 
     // RAW Processing
     m_Ui->four_color_rgb_CB->setChecked(luminance_options.isRawFourColorRGB());
     m_Ui->do_not_use_fuji_rotate_CB->setChecked(luminance_options.isRawDoNotUseFujiRotate());
+
+#ifdef DEMOSAICING_GPL2
+	bool GPL2 = true;
+#else
+	bool GPL2 = false;
+#endif
+#ifdef DEMOSAICING_GPL3
+	bool GPL3 = true;
+#else
+	bool GPL3 = false;
+#endif
+
+	int user_quality = luminance_options.getRawUserQuality();
+	if (user_quality < 4)	
+    	m_Ui->user_qual_comboBox->setCurrentIndex( user_quality );
+	else if ((GPL2 && GPL3) || (GPL2 && !GPL3)) // We have both demosaicing packs or only GPL2
+		m_Ui->user_qual_comboBox->setCurrentIndex( user_quality );
+	else // We have only GPL3
+		m_Ui->user_qual_comboBox->setCurrentIndex( 4 );
+
     m_Ui->user_qual_comboBox->setCurrentIndex(luminance_options.getRawUserQuality());
     m_Ui->med_passes_horizontalSlider->setValue(luminance_options.getRawMedPasses());
     m_Ui->med_passes_spinBox->setValue(luminance_options.getRawMedPasses());
@@ -636,7 +688,7 @@ void PreferencesDialog::from_options_to_gui()
 
     m_Ui->threshold_horizontalSlider->setValue( luminance_options.getRawNoiseReductionThreshold() );
     m_Ui->threshold_spinBox->setValue( luminance_options.getRawNoiseReductionThreshold() );
-    m_Ui->use_chroma_CB->setChecked( luminance_options.isRawUseChroma() );
+    m_Ui->use_chroma_CB->setChecked( luminance_options.isRawUseChromaAber() );
 
     double r_minv = m_Ui->red_doubleSpinBox->minimum();
     double r_maxv = m_Ui->red_doubleSpinBox->maximum();
@@ -697,33 +749,25 @@ void PreferencesDialog::enterWhatsThis()
 
 void PreferencesDialog::on_camera_toolButton_clicked()
 {
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Open ICC Profile"),
-		ICC_PATH,
-		tr("Color profile (*.icc *.ICC *.icm *.ICM)")
-	);
-	if (!fileName.isEmpty()) {
-		m_Ui->camera_lineEdit->setText(fileName);
-	}
+    openColorProfile(m_Ui->camera_lineEdit);
 }
 
 void PreferencesDialog::on_monitor_toolButton_clicked()
 {
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Open ICC Profile"),
-		ICC_PATH,
-		tr("Color profile (*.icc)")
-	);
-	if (!fileName.isEmpty()) {
-		m_Ui->monitor_lineEdit->setText(fileName);
-	}
+    openColorProfile(m_Ui->monitor_lineEdit);
 }
 
 void PreferencesDialog::on_printer_toolButton_clicked()
 {
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Open ICC Profile"),
+    openColorProfile(m_Ui->printer_lineEdit);
+}
+
+void PreferencesDialog::openColorProfile(QLineEdit* lineEdit)
+{
+    QString fileName = QFileDialog::getOpenFileName(this, tr("Open ICC Profile"),
 		ICC_PATH,
-		tr("Color profile (*.icc)")
+		tr("Color profile (*.icc *.ICC *.icm *.ICM)")
 	);
-	if (!fileName.isEmpty()) {
-		m_Ui->printer_lineEdit->setText(fileName);
-	}
+	if (!fileName.isEmpty())
+		lineEdit->setText(fileName);
 }
