@@ -30,67 +30,20 @@
 #include <stdlib.h>
 #include <cmath>
 #include <iostream>
-#include <assert.h>
+#include <cassert>
 
 #include <QFile>
 
-#include "Libpfs/colorspace.h"
+
 #include "Libpfs/frame.h"
-#include "Common/ProgressHelper.h"
+#include "Libpfs/colorspace/colorspace.h"
+#include "Libpfs/progress.h"
+
 #include "tmo_ashikhmin02.h"
 
-void calculateLuminance( pfs::Array2D* Y, float& avLum, float& maxLum, float& minLum);
-
-void pfstmo_ashikhmin02(pfs::Frame* inpfsframe,  bool simple_flag, float lc_value, int eq, ProgressHelper *ph)
+namespace
 {
-    assert(inpfsframe!=NULL);
-
-    //--- default tone mapping parameters;
-
-    std::cout << "pfstmo_ashikhmin02 (";
-    std::cout << "simple: " << simple_flag;
-    std::cout << ", lc_value: " << lc_value;
-    std::cout << ", eq: " << eq << ")" << std::endl;
-
-    pfs::Channel *X, *Y, *Z;
-    inpfsframe->getXYZChannels(X,Y,Z);
-    assert( X!=NULL && Y!=NULL && Z!=NULL );
-
-    pfs::Array2D* Xr = X->getChannelData();
-    pfs::Array2D* Yr = Y->getChannelData();
-    pfs::Array2D* Zr = Z->getChannelData();
-
-    pfs::transformColorSpace( pfs::CS_RGB, Xr, Yr, Zr, pfs::CS_XYZ, Xr, Yr, Zr );
-    float maxLum, avLum, minLum;
-    calculateLuminance( Yr, avLum, maxLum, minLum);
-
-    int w = Yr->getCols();
-    int h = Yr->getRows();
-
-    pfs::Array2D* L = new pfs::Array2D(w,h);
-    tmo_ashikhmin02(Yr, L, maxLum, minLum, avLum, simple_flag, lc_value, eq, ph);
-
-    // TODO: this section can be rewritten using SSE Function
-    for ( int x=0 ; x<w ; x++ )
-    {
-        for ( int y=0 ; y<h ; y++ )
-        {
-            float scale = (*L)(x,y) / (*Yr)(x,y);
-            (*Yr)(x,y) = (*Yr)(x,y) * scale;
-            (*Xr)(x,y) = (*Xr)(x,y) * scale;
-            (*Zr)(x,y) = (*Zr)(x,y) * scale;
-        }
-    }
-
-    if (!ph->isTerminationRequested())
-        ph->newValue( 100 );
-
-    delete L;
-
-    pfs::transformColorSpace(pfs::CS_XYZ, Xr, Yr, Zr, pfs::CS_RGB, Xr, Yr, Zr);
-}
-
-void calculateLuminance( pfs::Array2D* Y, float& avLum, float& maxLum, float& minLum)
+void calculateLuminance( pfs::Array2Df* Y, float& avLum, float& maxLum, float& minLum)
 {
     avLum = 0.0f;
     maxLum = 0.0f;
@@ -106,4 +59,51 @@ void calculateLuminance( pfs::Array2D* Y, float& avLum, float& maxLum, float& mi
     }
     avLum =exp( avLum/ size);
 }
+}
+
+void pfstmo_ashikhmin02(pfs::Frame& frame, bool simple_flag, float lc_value, int eq, pfs::Progress &ph)
+{
+#ifndef NDEBUG
+    //--- default tone mapping parameters;
+    std::cout << "pfstmo_ashikhmin02 (";
+    std::cout << "simple: " << simple_flag;
+    std::cout << ", lc_value: " << lc_value;
+    std::cout << ", eq: " << eq << ")" << std::endl;
+#endif
+
+    pfs::Channel *Xr, *Yr, *Zr;
+    frame.getXYZChannels(Xr, Yr, Zr);
+    assert( Xr != NULL );
+    assert( Yr != NULL );
+    assert( Zr != NULL );
+
+    pfs::transformColorSpace( pfs::CS_RGB, Xr, Yr, Zr, pfs::CS_XYZ, Xr, Yr, Zr );
+    float maxLum, avLum, minLum;
+    calculateLuminance(Yr, avLum, maxLum, minLum);
+
+    int w = Yr->getCols();
+    int h = Yr->getRows();
+
+    pfs::Array2Df L(w,h);
+    tmo_ashikhmin02(Yr, &L, maxLum, minLum, avLum, simple_flag, lc_value, eq, ph);
+
+    // TODO: this section can be rewritten using SSE Function
+    for ( int x=0 ; x<w ; x++ )
+    {
+        for ( int y=0 ; y<h ; y++ )
+        {
+            float scale = L(x,y) / (*Yr)(x,y);
+            (*Yr)(x,y) = (*Yr)(x,y) * scale;
+            (*Xr)(x,y) = (*Xr)(x,y) * scale;
+            (*Zr)(x,y) = (*Zr)(x,y) * scale;
+        }
+    }
+
+    if (!ph.canceled())
+    {
+        ph.setValue( 100 );
+    }
+
+    pfs::transformColorSpace(pfs::CS_XYZ, Xr, Yr, Zr, pfs::CS_RGB, Xr, Yr, Zr);
+}
 
