@@ -34,50 +34,54 @@
 #include <iostream>
 
 #include "Libpfs/frame.h"
-#include "Common/ProgressHelper.h"
+#include "Libpfs/progress.h"
+#include "Libpfs/exception.h"
 #include "tmo_drago03.h"
 
-void pfstmo_drago03(pfs::Frame *frame, float biasValue, ProgressHelper *ph)
+void pfstmo_drago03(pfs::Frame& frame, float biasValue, pfs::Progress &ph)
 {
     std::cout << "pfstmo_drago03 (";
     std::cout << "bias: " << biasValue << ")" << std::endl;
 
     pfs::Channel *X, *Y, *Z;
-    frame->getXYZChannels( X, Y, Z );
+    frame.getXYZChannels( X, Y, Z );
 
-    frame->getTags()->setString("LUMINANCE", "RELATIVE");
+    frame.getTags().setTag("LUMINANCE", "RELATIVE");
     //---
 
-    if( Y == NULL )
-        throw pfs::Exception( "Missing X, Y, Z channels in the PFS stream" );
-
-    pfs::Array2D *Xr = X->getChannelData();
-    pfs::Array2D *Yr = Y->getChannelData();
-    pfs::Array2D *Zr = Z->getChannelData();
-
-    int w = Yr->getCols();
-    int h = Yr->getRows();
-
-    float maxLum,avLum;
-    calculateLuminance( w, h, Yr->getRawData(), avLum, maxLum );
-
-    pfs::Array2D* L = new pfs::Array2D(w, h);
-    tmo_drago03(w, h, Yr->getRawData(), L->getRawData(), maxLum, avLum, biasValue, ph);
-
-    for( int x=0 ; x<w ; x++ )
+    if ( Y == NULL )
     {
-        for( int y=0 ; y<h ; y++ )
+        throw pfs::Exception( "Missing X, Y, Z channels in the PFS stream" );
+    }
+
+    pfs::Array2Df& Xr = *X;
+    pfs::Array2Df& Yr = *Y;
+    pfs::Array2Df& Zr = *Z;
+
+    int w = Yr.getCols();
+    int h = Yr.getRows();
+
+    float maxLum;
+    float avLum;
+    calculateLuminance(w, h, Yr.data(), avLum, maxLum);
+
+    pfs::Array2Df L(w, h);
+    tmo_drago03(Yr, L, maxLum, avLum, biasValue, ph);
+
+    for (int x=0 ; x<w ; x++)
+    {
+        for (int y=0 ; y<h ; y++)
         {
-            float scale = (*L)(x,y) / (*Yr)(x,y);
-            (*Yr)(x,y) *= scale;
-            (*Xr)(x,y) *= scale;
-            (*Zr)(x,y) *= scale;
+            float scale = L(x,y) / Yr(x,y);
+            Yr(x,y) = Yr(x,y) * scale;
+            Xr(x,y) = Xr(x,y) * scale;
+            Zr(x,y) = Zr(x,y) * scale;
         }
     }
 
-    if (!ph->isTerminationRequested())
-        ph->newValue( 100 );
-
-    delete L;
+    if (!ph.canceled())
+    {
+        ph.setValue( 100 );
+    }
 }
 
