@@ -32,27 +32,24 @@
 #ifndef BILATERAL_H
 #define BILATERAL_H
 
-// forward declaration
-class ProgressHelper;
-
-namespace pfs {
-    class Array2D;
+namespace pfs
+{
+class Array2D;
+class Progress;
 }
 
-/**
- * @brief Bilateral filtering
- *
- * Conventional (slow) algorithm.
- *
- * @param I [in] input array
- * @param J [out] filtered array
- * @param sigma_s sigma value for spatial kernel
- * @param sigma_r sigma value for range kernel
- *
- * $Id: bilateral.h,v 1.3 2008/09/09 00:56:49 rafm Exp $
- */
-void bilateralFilter( const pfs::Array2D *I, pfs::Array2D *J,
-                      float sigma_s, float sigma_r,
-                      ProgressHelper *ph );
+//!
+//! @brief Bilateral filtering
+//!
+//! Conventional (slow) algorithm.
+//!
+//! \param I [in] input array
+//! \param J [out] filtered array
+//! \param sigma_s sigma value for spatial kernel
+//! \param sigma_r sigma value for range kernel
+//!
+void bilateralFilter(const pfs::Array2D *I, pfs::Array2D *J,
+                     float sigma_s, float sigma_r,
+                     pfs::Progress& ph);
 
-#endif /* #ifndef _bilateral_h_ */
+#endif /* #ifndef BILATERAL_H */
