@@ -39,15 +39,16 @@
 #include <algorithm>
 
 #include "Libpfs/frame.h"
-#include "Libpfs/colorspace.h"
-#include "Common/ProgressHelper.h"
+#include "Libpfs/colorspace/colorspace.h"
+#include "Libpfs/exception.h"
+#include "Libpfs/progress.h"
 
 namespace
 {
 const float epsilon = 1e-4f;
 }
 
-void pfstmo_fattal02(pfs::Frame* frame,
+void pfstmo_fattal02(pfs::Frame& frame,
                      float opt_alpha,
                      float opt_beta,
                      float opt_saturation,
@@ -55,7 +56,7 @@ void pfstmo_fattal02(pfs::Frame* frame,
                      bool newfattal,
                      bool fftsolver,
                      int detail_level,
-                     ProgressHelper *ph)
+                     pfs::Progress &ph)
 {
   if (fftsolver)
   {
@@ -67,7 +68,7 @@ void pfstmo_fattal02(pfs::Frame* frame,
   {
       opt_noise = opt_alpha * 0.01f;
   }
-  
+#ifndef NDEBUG
   std::stringstream ss;
   ss << "pfstmo_fattal02 (";
   ss << "alpha: " << opt_alpha;
@@ -75,56 +76,49 @@ void pfstmo_fattal02(pfs::Frame* frame,
   ss << ". saturation: " <<  opt_saturation;
   ss << ", noise: " <<  opt_noise;
   ss << ", fftsolver: " << fftsolver << ")";
-  std::cout << ss.str();
-  std::cout << std::endl;
-  
+  std::cout << ss.str() << std::endl;
+#endif
+
   //Store RGB data temporarily in XYZ channels
-  pfs::Channel *X, *Y, *Z;
-  frame->getXYZChannels( X, Y, Z );
-  frame->getTags()->setString("LUMINANCE", "RELATIVE");
+  pfs::Channel *R, *G, *B;
+  frame.getXYZChannels( R, G, B );
+  frame.getTags().setTag("LUMINANCE", "RELATIVE");
   //---
   
-  if ( Y==NULL || X==NULL || Z==NULL )
+  if ( !R || !G || !B )
   {
       throw pfs::Exception( "Missing X, Y, Z channels in the PFS stream" );
   }
-  
-  pfs::Array2D& Xr = *X->getChannelData();
-  pfs::Array2D& Yr = *Y->getChannelData();
-  pfs::Array2D& Zr = *Z->getChannelData();
-  
+    
   // tone mapping
-  int w = Y->getWidth();
-  int h = Y->getHeight();
+  int w = frame.getWidth();
+  int h = frame.getHeight();
   
-  pfs::Array2D L(w,h);
+  pfs::Array2Df Yr(w,h);
+  pfs::Array2Df L(w,h);
+
+  pfs::transformRGB2Y(R, G, B, &Yr);
 
   tmo_fattal02(w, h, Yr, L,
                opt_alpha, opt_beta, opt_noise, newfattal,
                fftsolver, detail_level,
                ph);
 
-  if ( !ph->isTerminationRequested() )
+  if ( !ph.canceled() )
   {
-      pfs::Array2D G(w, h);
-      pfs::Array2D& R = Xr;
-      pfs::Array2D& B = Zr;
-
-      pfs::transformColorSpace(pfs::CS_XYZ, &Xr, &Yr, &Zr,
-                               pfs::CS_RGB, &R, &G, &B);
+      pfs::Array2Df& arrayRed = *R;
+      pfs::Array2Df& arrayGreen = *G;
+      pfs::Array2Df& arrayBlue = *B;
 
       for (int i=0; i < w*h; i++)
       {
           float y = std::max( Yr(i), epsilon );
           float l = std::max( L(i), epsilon );
-          R(i) = powf( std::max(R(i)/y, 0.f), opt_saturation ) * l;
-          G(i) = powf( std::max(G(i)/y, 0.f), opt_saturation ) * l;
-          B(i) = powf( std::max(B(i)/y, 0.f), opt_saturation ) * l;
+          arrayRed(i) = std::pow( std::max(arrayRed(i)/y, 0.f), opt_saturation ) * l;
+          arrayGreen(i) = std::pow( std::max(arrayGreen(i)/y, 0.f), opt_saturation ) * l;
+          arrayBlue(i) = std::pow( std::max(arrayBlue(i)/y, 0.f), opt_saturation ) * l;
       }
 
-      pfs::transformColorSpace(pfs::CS_RGB, &R, &G, &B,
-                               pfs::CS_XYZ, &Xr, &Yr, &Zr);
-
-      ph->newValue( 100 );
+      ph.setValue( 100 );
   }
 }
