@@ -33,14 +33,17 @@
 
 #include <cstdio>
 #include <iostream>
+#include <iterator>
 #include <vector>
 #include <algorithm>
 
 #include <math.h>
 #include <assert.h>
 
+#include "Libpfs/array2d.h"
+#include "Libpfs/progress.h"
 #include "TonemappingOperators/pfstmo.h"
-#include "Common/ProgressHelper.h"
+
 #include "pde.h"
 #include "tmo_fattal02.h"
 
@@ -70,7 +73,7 @@ using namespace std;
 
 //--------------------------------------------------------------------
 
-void downSample(const pfs::Array2D& A, pfs::Array2D& B)
+void downSample(const pfs::Array2Df& A, pfs::Array2Df& B)
 {
     const int width = B.getCols();
     const int height = B.getRows();
@@ -93,12 +96,12 @@ void downSample(const pfs::Array2D& A, pfs::Array2D& B)
     }
 }
 	
-void gaussianBlur(const pfs::Array2D& I, pfs::Array2D& L)
+void gaussianBlur(const pfs::Array2Df& I, pfs::Array2Df& L)
 {
     const int width = I.getCols();
     const int height = I.getRows();
 
-    pfs::Array2D T(width,height);
+    pfs::Array2Df T(width,height);
 
     //--- X blur
     //#pragma omp parallel for shared(I, T)
@@ -131,29 +134,29 @@ void gaussianBlur(const pfs::Array2D& I, pfs::Array2D& L)
     }
 }
 
-void createGaussianPyramids( pfs::Array2D* H, pfs::Array2D** pyramids, int nlevels)
+void createGaussianPyramids( pfs::Array2Df* H, pfs::Array2Df** pyramids, int nlevels)
 {
   int width = H->getCols();
   int height = H->getRows();
   const int size = width*height;
 
-  pyramids[0] = new pfs::Array2D(width,height);
+  pyramids[0] = new pfs::Array2Df(width,height);
 //#pragma omp parallel for shared(pyramids, H)
   for( int i=0 ; i<size ; i++ )
     (*pyramids[0])(i) = (*H)(i);
 
-  pfs::Array2D* L = new pfs::Array2D(width,height);
+  pfs::Array2Df* L = new pfs::Array2Df(width,height);
   gaussianBlur( *pyramids[0], *L );
 	
   for ( int k=1 ; k<nlevels ; k++ )
   {
     width /= 2;
     height /= 2;		
-    pyramids[k] = new pfs::Array2D(width,height);
+    pyramids[k] = new pfs::Array2Df(width,height);
     downSample(*L, *pyramids[k]);
     
     delete L;
-    L = new pfs::Array2D(width,height);
+    L = new pfs::Array2Df(width,height);
     gaussianBlur( *pyramids[k], *L );
   }
 
@@ -162,7 +165,7 @@ void createGaussianPyramids( pfs::Array2D* H, pfs::Array2D** pyramids, int nleve
 
 //--------------------------------------------------------------------
 
-float calculateGradients(pfs::Array2D* H, pfs::Array2D* G, int k)
+float calculateGradients(pfs::Array2Df* H, pfs::Array2Df* G, int k)
 {
   const int width = H->getCols();
   const int height = H->getRows();
@@ -199,7 +202,7 @@ float calculateGradients(pfs::Array2D* H, pfs::Array2D* G, int k)
 
 //--------------------------------------------------------------------
 
-void upSample(const pfs::Array2D& A, pfs::Array2D& B)
+void upSample(const pfs::Array2Df& A, pfs::Array2Df& B)
 {
     const int width = B.getCols();
     const int height = B.getRows();
@@ -235,15 +238,15 @@ void upSample(const pfs::Array2D& A, pfs::Array2D& B)
 }
 
 
-void calculateFiMatrix(pfs::Array2D* FI, pfs::Array2D* gradients[],
+void calculateFiMatrix(pfs::Array2Df* FI, pfs::Array2Df* gradients[],
                        float avgGrad[], int nlevels, int detail_level,
                        float alfa, float beta, float noise, bool newfattal)
 {
     int width = gradients[nlevels-1]->getCols();
     int height = gradients[nlevels-1]->getRows();
-    pfs::Array2D** fi = new pfs::Array2D*[nlevels];
+    pfs::Array2Df** fi = new pfs::Array2Df*[nlevels];
 
-    fi[nlevels-1] = new pfs::Array2D(width,height);
+    fi[nlevels-1] = new pfs::Array2Df(width,height);
     if (newfattal)
     {
         //#pragma omp parallel for shared(fi)
@@ -288,7 +291,7 @@ void calculateFiMatrix(pfs::Array2D* FI, pfs::Array2D* gradients[],
         {
             width = gradients[k-1]->getCols();
             height = gradients[k-1]->getRows();
-            fi[k-1] = new pfs::Array2D(width,height);
+            fi[k-1] = new pfs::Array2Df(width,height);
         }
         else
             fi[0] = FI;                         // highest level -> result
@@ -308,14 +311,14 @@ void calculateFiMatrix(pfs::Array2D* FI, pfs::Array2D* gradients[],
 }
 
 inline
-void findMaxMinPercentile(const pfs::Array2D& I,
+void findMaxMinPercentile(const pfs::Array2Df& I,
                                  float minPrct, float& minLum,
                                  float maxPrct, float& maxLum)
 {
     using namespace std;
 
     const int size = I.getRows() * I.getCols();
-    const float* data = I.getRawData();
+    const float* data = I.data();
     std::vector<float> vI;
 
     copy(data, data + size, back_inserter(vI));
@@ -327,17 +330,15 @@ void findMaxMinPercentile(const pfs::Array2D& I,
 
 void tmo_fattal02(size_t width,
                   size_t height,
-                  const pfs::Array2D& Y,
-                  //const float* nY,
-                  pfs::Array2D& L,
-                  //float* nL,
+                  const pfs::Array2Df& Y,
+                  pfs::Array2Df& L,
                   float alfa,
                   float beta,
                   float noise,
                   bool newfattal,
                   bool fftsolver,
                   int detail_level,
-                  ProgressHelper *ph)
+                  pfs::Progress &ph)
 {
     static const float black_point = 0.1f;
     static const float white_point = 0.5f;
@@ -346,8 +347,8 @@ void tmo_fattal02(size_t width,
     if ( detail_level < 0 ) detail_level = 0;
     if ( detail_level > 3 ) detail_level = 3;
 
-  ph->newValue(2);
-  if (ph->isTerminationRequested()) return;
+  ph.setValue(2);
+  if (ph.canceled()) return;
 
   int MSIZE = 32;         // minimum size of gaussian pyramid
   // I believe a smaller value than 32 results in slightly better overall
@@ -371,13 +372,13 @@ void tmo_fattal02(size_t width,
       minLum = ( Y(i) < minLum ) ? Y(i) : minLum;
       maxLum = ( Y(i) > maxLum ) ? Y(i) : maxLum;
   }
-  pfs::Array2D* H = new pfs::Array2D(width, height);
+  pfs::Array2Df* H = new pfs::Array2Df(width, height);
   //#pragma omp parallel for private(i) shared(H, Y, maxLum)
   for ( int i=0 ; i<size ; i++ )
   {
       (*H)(i) = logf( 100.0f* Y(i)/maxLum + 1e-4 );
   }
-  ph->newValue(4);
+  ph.setValue(4);
 
   // create gaussian pyramids
   int mins = (width<height) ? width : height;	// smaller dimension
@@ -391,22 +392,22 @@ void tmo_fattal02(size_t width,
   // The following lines solves a bug with images particularly small
   if (nlevels == 0) nlevels = 1;
 
-  pfs::Array2D** pyramids = new pfs::Array2D*[nlevels];
+  pfs::Array2Df** pyramids = new pfs::Array2Df*[nlevels];
   createGaussianPyramids(H, pyramids, nlevels);
-  ph->newValue(8);
+  ph.setValue(8);
 
   // calculate gradients and its average values on pyramid levels
-  pfs::Array2D** gradients = new pfs::Array2D*[nlevels];
+  pfs::Array2Df** gradients = new pfs::Array2Df*[nlevels];
   float* avgGrad = new float[nlevels];
   for ( int k=0 ; k<nlevels ; k++ )
   {
-    gradients[k] = new pfs::Array2D(pyramids[k]->getCols(), pyramids[k]->getRows());
+    gradients[k] = new pfs::Array2Df(pyramids[k]->getCols(), pyramids[k]->getRows());
     avgGrad[k] = calculateGradients(pyramids[k],gradients[k], k);
   }
-  ph->newValue(12);
+  ph.setValue(12);
 
   // calculate fi matrix
-  pfs::Array2D* FI = new pfs::Array2D(width, height);
+  pfs::Array2Df* FI = new pfs::Array2Df(width, height);
   calculateFiMatrix(FI, gradients, avgGrad, nlevels, detail_level, alfa, beta, noise, newfattal);
 //  dumpPFS( "FI.pfs", FI, "Y" );
   for ( int i=0 ; i<nlevels ; i++ )
@@ -417,8 +418,8 @@ void tmo_fattal02(size_t width,
   delete[] pyramids;
   delete[] gradients;
   delete[] avgGrad;
-  ph->newValue(16);
-  if (ph->isTerminationRequested()){
+  ph.setValue(16);
+  if (ph.canceled()){
     delete FI;
     delete H;
     return;
@@ -426,8 +427,8 @@ void tmo_fattal02(size_t width,
 
 
   // attenuate gradients
-  pfs::Array2D* Gx = new pfs::Array2D(width, height);
-  pfs::Array2D* Gy = new pfs::Array2D(width, height);
+  pfs::Array2Df* Gx = new pfs::Array2Df(width, height);
+  pfs::Array2Df* Gy = new pfs::Array2Df(width, height);
 
   // the fft solver solves the Poisson pde but with slightly different
   // boundary conditions, so we need to adjust the assembly of the right hand
@@ -457,14 +458,14 @@ void tmo_fattal02(size_t width,
       }
   delete H;
   delete FI;
-  ph->newValue(18);
+  ph.setValue(18);
 
 
 //   dumpPFS( "Gx.pfs", Gx, "Y" );
 //   dumpPFS( "Gy.pfs", Gy, "Y" );
   
   // calculate divergence
-  pfs::Array2D DivG(width, height);
+  pfs::Array2Df DivG(width, height);
   for ( size_t y = 0; y < height; ++y )
   {
       for ( size_t x = 0; x < width; ++x )
@@ -483,8 +484,8 @@ void tmo_fattal02(size_t width,
   }
   delete Gx;
   delete Gy;
-  ph->newValue(20);
-  if (ph->isTerminationRequested())
+  ph.setValue(20);
+  if (ph.canceled())
   {
       return;
   }
@@ -493,7 +494,7 @@ void tmo_fattal02(size_t width,
   
   // solve pde and exponentiate (ie recover compressed image)
   {
-  pfs::Array2D U(width, height);
+  pfs::Array2Df U(width, height);
   if (fftsolver)
   {
       solve_pde_fft(&DivG, &U, ph);
@@ -503,8 +504,8 @@ void tmo_fattal02(size_t width,
       solve_pde_multigrid(&DivG, &U, ph);
   }
   printf("\npde residual error: %f\n", residual_pde(&U, &DivG));
-  ph->newValue(90); 
-  if ( ph->isTerminationRequested() )
+  ph.setValue(90);
+  if ( ph.canceled() )
   {
       return;
   }
@@ -514,7 +515,7 @@ void tmo_fattal02(size_t width,
       L(idx) = expf( gamma * U(idx) );
   }
   }
-  ph->newValue(95); 
+  ph.setValue(95);
 	
   // remove percentile of min and max values and renormalize
   float cut_min = 0.01f * black_point;
@@ -531,5 +532,5 @@ void tmo_fattal02(size_t width,
       // note, we intentionally do not cut off values > 1.0
   }
 
-  ph->newValue(96); 
+  ph.setValue(96);
 }
