@@ -32,9 +32,11 @@
 #ifndef DISPLAY_FUNCTION_H
 #define DISPLAY_FUNCTION_H
 
-#include <stdio.h>
+#include <cstdio>
+
 #include "arch/math.h"
-#include "Libpfs/vex.h"
+#include "Libpfs/utils/sse.h"
+#include <Libpfs/exception.h>
 
 class DisplayFunction
 {
