@@ -35,14 +35,33 @@
 
 #include <iostream>
 #include <cmath>
+#include <algorithm>
+#include <boost/scoped_ptr.hpp>
 
 #include "Libpfs/frame.h"
-#include "Libpfs/colorspace.h"
-#include "Common/ProgressHelper.h"
+#include "Libpfs/colorspace/colorspace.h"
+#include "Libpfs/exception.h"
+#include "Libpfs/progress.h"
 
-void multiplyChannels( pfs::Array2D* X, pfs::Array2D* Y, pfs::Array2D* Z, float mult );
+namespace
+{
+void multiplyChannels( pfs::Array2Df& X, pfs::Array2Df& Y, pfs::Array2Df& Z, float mult )
+{
+    int size = Y.getCols() * Y.getRows();
 
-void pfstmo_pattanaik00(pfs::Frame* frame, bool local, float multiplier, float Acone, float Arod, bool autolum, ProgressHelper *ph)
+    for ( int i=0 ; i<size; i++ )
+    {
+        X(i) *= mult;
+        Y(i) *= mult;
+        Z(i) *= mult;
+    }
+}
+}
+
+void pfstmo_pattanaik00(pfs::Frame& frame,
+                        bool local, float multiplier,
+                        float Acone, float Arod, bool autolum,
+                        pfs::Progress &ph)
 {  
     //--- default tone mapping parameters;
     bool timedependence = false;
@@ -59,64 +78,49 @@ void pfstmo_pattanaik00(pfs::Frame* frame, bool local, float multiplier, float A
     std::cout << "Arod: " << Arod << ", ";
     std::cout << "autolum: " << autolum << ")" << std::endl;
 
-    VisualAdaptationModel* am = new VisualAdaptationModel();
+    boost::scoped_ptr<VisualAdaptationModel> am(new VisualAdaptationModel());
 
     pfs::Channel *X, *Y, *Z;
-    frame->getXYZChannels( X, Y, Z );
-    frame->getTags()->setString("LUMINANCE", "RELATIVE");
+    frame.getXYZChannels( X, Y, Z );
+    frame.getTags().setTag("LUMINANCE", "RELATIVE");
     //---
 
-    if( Y==NULL || X==NULL || Z==NULL)
+    if ( Y==NULL || X==NULL || Z==NULL)
+    {
         throw pfs::Exception( "Missing X, Y, Z channels in the PFS stream" );
-
-    pfs::Array2D* Xr = X->getChannelData();
-    pfs::Array2D* Yr = Y->getChannelData();
-    pfs::Array2D* Zr = Z->getChannelData();
+    }
 
     // adaptation model
-    if( multiplier != 1.0f )
-        multiplyChannels(Xr, Yr, Zr, multiplier );
+    if ( multiplier != 1.0f ) {
+        multiplyChannels(*X, *Y, *Z, multiplier );
+    }
 
     if( !local )
     {
         if( !timedependence )
         {
             if( !autolum )
-                am->setAdaptation(Acone,Arod);
+                am->setAdaptation(Acone, Arod);
             else
-                am->setAdaptation(Yr);
+                am->setAdaptation(*Y);
         }
         else
-            am->calculateAdaptation(Yr, 1.0f/fps);
+            am->calculateAdaptation(*Y, 1.0f/fps);
     }
     // tone mapping
     int w = Y->getWidth();
     int h = Y->getHeight();
-    pfs::Array2D* R = new pfs::Array2D(w,h);
-    pfs::Array2D* G = new pfs::Array2D(w,h);
-    pfs::Array2D* B = new pfs::Array2D(w,h);
 
-    pfs::transformColorSpace( pfs::CS_XYZ, Xr, Yr, Zr, pfs::CS_RGB, R, G, B );
-    tmo_pattanaik00( w, h, R->getRawData(), G->getRawData(), B->getRawData(), Y->getRawData(), am, local, ph );
-    pfs::transformColorSpace( pfs::CS_RGB, R, G, B, pfs::CS_XYZ, Xr, Yr, Zr );
+    pfs::Array2Df R(w,h);
+    pfs::Array2Df G(w,h);
+    pfs::Array2Df B(w,h);
 
-    if (!ph->isTerminationRequested())
-        ph->newValue(100);
+    pfs::transformColorSpace( pfs::CS_XYZ, X, Y, Z, pfs::CS_RGB, &R, &G, &B );
+    tmo_pattanaik00( R, G, B, *Y, am.get(), local, ph );
+    pfs::transformColorSpace( pfs::CS_RGB, &R, &G, &B, pfs::CS_XYZ, X, Y, Z );
 
-    delete R;
-    delete G;
-    delete B;
-    delete am; // delete visual adaptation model
-}
-
-void multiplyChannels( pfs::Array2D* X, pfs::Array2D* Y, pfs::Array2D* Z, float mult )
-{
-  int size = Y->getCols() * Y->getRows();
-  
-  for( int i=0 ; i<size; i++ )
-  {
-    (*X)(i) *= mult;
-    (*Y)(i) *= mult;
-    (*Z)(i) *= mult;
-  }
+    if (!ph.canceled())
+    {
+        ph.setValue(100);
+    }
 }
