@@ -38,10 +38,11 @@
 #include <cmath>
 
 #include "Libpfs/frame.h"
-#include "Libpfs/colorspace.h"
-#include "Common/ProgressHelper.h"
+#include "Libpfs/colorspace/colorspace.h"
+#include "Libpfs/exception.h"
+#include "Libpfs/progress.h"
 
-void pfstmo_reinhard05(pfs::Frame *frame, float brightness, float chromaticadaptation, float lightadaptation, ProgressHelper *ph)
+void pfstmo_reinhard05(pfs::Frame &frame, float brightness, float chromaticadaptation, float lightadaptation, pfs::Progress &ph)
 {  
     //--- default tone mapping parameters;
     //float brightness = 0.0f;
@@ -57,32 +58,29 @@ void pfstmo_reinhard05(pfs::Frame *frame, float brightness, float chromaticadapt
 
     std::cout << ss.str();
 
-    pfs::Channel *X, *Y, *Z;
-    frame->getXYZChannels( X, Y, Z );
-    frame->getTags()->setString("LUMINANCE", "RELATIVE");
+    pfs::Channel *R, *G, *B;
+    frame.getXYZChannels( R, G, B );
+    frame.getTags().setTag("LUMINANCE", "RELATIVE");
     //---
 
-    if( Y==NULL || X==NULL || Z==NULL)
+    if ( !R || !G || !B )
+    {
         throw pfs::Exception( "Missing X, Y, Z channels in the PFS stream" );
-
-    pfs::Array2D* Xr = X->getChannelData();
-    pfs::Array2D* Yr = Y->getChannelData();
-    pfs::Array2D* Zr = Z->getChannelData();
+    }
 
     // tone mapping
-    int w = Y->getWidth();
-    int h = Y->getHeight();
+    const unsigned int width = frame.getWidth();
+    const unsigned int height = frame.getHeight();
 
-    pfs::Array2D R(w,h);
-    pfs::Array2D G(w,h);
-    pfs::Array2D B(w,h);
+    // is there a way to remove this copy as well?
+    // I am pretty sure there is!
+    pfs::Array2Df Y(width,height);
+    pfs::transformRGB2Y(R, G, B, &Y);
+    tmo_reinhard05(width, height, R->data(), G->data(), B->data(), Y.data(),
+                   Reinhard05Params(brightness, chromaticadaptation, lightadaptation), ph);
 
-    pfs::transformColorSpace( pfs::CS_XYZ, Xr, Yr, Zr, pfs::CS_RGB, &R, &G, &B );
-
-    tmo_reinhard05(w, h, R.getRawData(), G.getRawData(), B.getRawData(), Y->getRawData(), brightness, chromaticadaptation, lightadaptation, ph );
-
-    pfs::transformColorSpace( pfs::CS_RGB, &R, &G, &B, pfs::CS_XYZ, Xr, Yr, Zr );
-
-    if (!ph->isTerminationRequested())
-        ph->newValue( 100 );
+    if (!ph.canceled())
+    {
+        ph.setValue( 100 );
+    }
 }
