@@ -33,23 +33,46 @@
 #ifndef TMO_REINHARD05_H
 #define TMO_REINHARD05_H
 
-class ProgressHelper;
+#include <cstddef>
 
-/**
- * @brief: Tone mapping algorithm [Reinhard2005]
- *
- * @param width image width
- * @param height image height
- * @param R red channel
- * @param G green channel
- * @param B blue channel
- * @param Y luminance channel
- * @param br brightness level -8:8 (def 0)
- * @param ca amount of chromatic adaptation 0:1 (saturation, def 0)
- * @param la amount of light adaptation 0:1 (local/global, def 1)
- */
-void tmo_reinhard05(unsigned int width, unsigned int height,
-  float* R, float* G, float* B, 
-  const float* Y, float br, float ca, float la, ProgressHelper *ph );
+namespace pfs
+{
+class Progress;
+}
+
+struct Reinhard05Params
+{
+    Reinhard05Params(float brightness,
+                     float chromaticAdaptation,
+                     float lightAdaptation)
+        : m_brightness(brightness)
+        , m_chromaticAdaptation(chromaticAdaptation)
+        , m_lightAdaptation(lightAdaptation)
+    {
+        // ideally double check that parameters are not outside
+        // of the allowed range!
+    }
+
+    float m_brightness;
+    float m_chromaticAdaptation;
+    float m_lightAdaptation;
+};
+
+//! \brief: Tone mapping algorithm [Reinhard2005]
+//!
+//! \param width image width
+//! \param height image height
+//! \param R red channel
+//! \param G green channel
+//! \param B blue channel
+//! \param Y luminance channel
+//! \param br brightness level -8:8 (def 0)
+//! \param ca amount of chromatic adaptation 0:1 (saturation, def 0)
+//! \param la amount of light adaptation 0:1 (local/global, def 1)
+void tmo_reinhard05(size_t width, size_t height,
+                    float* R, float* G, float* B,
+                    const float* Y,
+                    const Reinhard05Params& params,
+                    pfs::Progress &ph);
 
 #endif // TMO_REINHARD05_H
