@@ -32,11 +32,11 @@
 #include <QGraphicsScene>
 #include <QGraphicsPixmapItem>
 
-#include "Common/FloatRgbToQRgb.h"
+#include <Libpfs/colorspace/rgbremapper_fwd.h>
 
 // Forward declaration
 namespace pfs {
-    class Frame;            // #include "Libpfs/frame.h"
+class Frame;                // #include "Libpfs/frame.h"
 }
 
 class PanIconWidget;        // #include "Common/PanIconWidget.h"
@@ -87,6 +87,9 @@ public:
     virtual TonemappingOptions* getTonemappingOptions() { return NULL; }
 
 public Q_SLOTS:
+    //! \brief Update viewer's pixmap when a new frame is set by setFrame() or AWB is performed
+    virtual void updatePixmap() = 0;
+
     /*virtual*/ void updateView();  // tells the Viewer to update the View area
 
     /*virtual*/ void zoomIn();
@@ -131,7 +134,7 @@ public Q_SLOTS:
     virtual float getMinLuminanceValue() = 0;
 
     //! \brief returns the mapping method
-    virtual LumMappingMethod getLuminanceMappingMethod()
+    virtual RGBMappingType getLuminanceMappingMethod()
     {
         return MAP_LINEAR;
     }
@@ -164,9 +167,6 @@ protected Q_SLOTS:
     /*virtual*/  void slotCornerButtonPressed();
     /*virtual*/  void scrollBarChanged(int /*value*/);
 
-    //! \brief Update viewer's pixmap when a new frame is set by setFrame()
-    virtual void updatePixmap() = 0;
-
 	void startDragging();
 
 protected:
