@@ -35,14 +35,17 @@
 #include "Viewers/LdrViewer.h"
 #include "Viewers/IGraphicsPixmapItem.h"
 #include "Core/TonemappingOptions.h"
-#include "Libpfs/frame.h"
 #include "Fileformat/pfsoutldrimage.h"
 #include "Common/LuminanceOptions.h"
-#include "Common/ResourceHandlerLcms.h"
+
+#include <Libpfs/frame.h>
+#include <Libpfs/utils/resourcehandlerlcms.h>
+
+using namespace pfs;
 
 namespace
 {
-void parseOptions(const TonemappingOptions *opts, QString& caption)
+void parseOptions(TonemappingOptions *opts, QString& caption)
 {
     if (opts == NULL)
     {
@@ -51,13 +54,13 @@ void parseOptions(const TonemappingOptions *opts, QString& caption)
     else
     {
         TMOptionsOperations tmopts(opts);
-        //postfix = tmopts.getPostfix();
-        caption = tmopts.getCaption();
+        //postfix = opts->getPostfix();
+        caption = opts->getCaption();
         //exif_comment = tmopts.getExifComment();
     }
 }
 
-QImage* doCMSTransform(QImage* input_qimage, bool doProof, bool doGamutCheck)
+bool doCMSTransform(QImage& qImage, bool doProof, bool doGamutCheck)
 {
     LuminanceOptions luminance_opts;
     QString monitor_fname = luminance_opts.getMonitorProfileFileName();
@@ -65,21 +68,20 @@ QImage* doCMSTransform(QImage* input_qimage, bool doProof, bool doGamutCheck)
     QString printer_fname = luminance_opts.getPrinterProfileFileName();
     qDebug() << "Printer profile: " << printer_fname;
 
-    // CHECK MONITOR PROFILE NAME
-    // TODO: Check inside LuminanceOptions whether the file is on the filesystem
-    // or it has been removed!
-    if ( monitor_fname.isEmpty() ) return NULL;
+    // Check Monitor Profile
+    if ( monitor_fname.isEmpty() )
+    {
+        return false;
+    }
 
-    qDebug() << "Transform to Monitor Profile";
-    QByteArray iccProfileMonitor( QFile::encodeName( monitor_fname ) );
+    utils::ScopedCmsProfile hsRGB( cmsCreate_sRGBProfile() );
+    utils::ScopedCmsProfile hOut(
+                cmsOpenProfileFromFile(
+                    QFile::encodeName( monitor_fname ).constData(), "r")
+                );
 
-    QScopedPointer<QImage> out_qimage( new QImage(input_qimage->width(), input_qimage->height(), QImage::Format_RGB32) );
-
-    ScopedCmsProfile hsRGB( cmsCreate_sRGBProfile() );
-    ScopedCmsProfile hOut( cmsOpenProfileFromFile(iccProfileMonitor.constData(), "r") );
-
-    ScopedCmsProfile hProof;
-    ScopedCmsTransform xform;
+    utils::ScopedCmsProfile hProof;
+    utils::ScopedCmsTransform xform;
 
     // Check whether the output profile is open
     if ( !hOut )
@@ -89,14 +91,16 @@ QImage* doCMSTransform(QImage* input_qimage, bool doProof, bool doGamutCheck)
                              QObject::tr("I cannot open monitor profile. Please select a different one."),
                              QMessageBox::Ok, QMessageBox::NoButton);
 
-        return NULL;
+        return false;
     }
 
     //
     if (doProof && !printer_fname.isEmpty())
     {
-        QByteArray iccProfilePrinter( QFile::encodeName( printer_fname ) );
-        hProof.reset( cmsOpenProfileFromFile(iccProfilePrinter.constData(), "r") );
+        hProof.reset(
+                    cmsOpenProfileFromFile(
+                        QFile::encodeName( printer_fname ).constData(), "r")
+                    );
         if ( !hProof )
         {
             QMessageBox::warning(0,
@@ -139,23 +143,21 @@ QImage* doCMSTransform(QImage* input_qimage, bool doProof, bool doGamutCheck)
                              QObject::tr("I cannot perform the color transform. Please select a different monitor profile."),
                              QMessageBox::Ok, QMessageBox::NoButton);
 
-        return NULL;
+        return false;
     }
 
-    cmsDoTransform(xform.data(),
-                   input_qimage->bits(),
-                   out_qimage->bits(),
-                   (input_qimage->width() * input_qimage->height()) );
+    cmsDoTransform( xform.data(), qImage.bits(), qImage.bits(),
+                    qImage.width()*qImage.height() );
 
-    return out_qimage.take();
+    return true;
 }
 }
 
-
-LdrViewer::LdrViewer(pfs::Frame* frame, TonemappingOptions* opts, QWidget *parent, bool ns):
-    GenericViewer(frame, parent, ns),
-    informativeLabel(new QLabel( mToolBar)),
-    mTonemappingOptions(opts)
+// This constructor is a bit of a mess!
+LdrViewer::LdrViewer(pfs::Frame* frame, TonemappingOptions* opts, QWidget *parent, bool ns)
+    : GenericViewer(frame, parent, ns)
+    , informativeLabel(new QLabel(mToolBar))
+    , mTonemappingOptions(opts)
 {
     mToolBar->addWidget(informativeLabel);
 
@@ -167,16 +169,8 @@ LdrViewer::LdrViewer(pfs::Frame* frame, TonemappingOptions* opts, QWidget *paren
     LdrViewer::setTonemappingOptions(opts);
 
     QScopedPointer<QImage> temp_qimage( fromLDRPFStoQImage(getFrame()) );
-    QScopedPointer<QImage> xformed_qimage( doCMSTransform(temp_qimage.data(), false, false) );
-
-    if (xformed_qimage == NULL)
-    {
-        setQImage(*temp_qimage);
-    }
-    else
-    {
-        setQImage(*xformed_qimage);
-    }
+    doCMSTransform(*temp_qimage, false, false);
+    setQImage(*temp_qimage);
 
     updateView();
     retranslateUi();
@@ -198,12 +192,7 @@ void LdrViewer::retranslateUi()
 
 QString LdrViewer::getFileNamePostFix()
 {
-    if ( mTonemappingOptions )
-    {
-        TMOptionsOperations tm_ops(mTonemappingOptions);
-        return tm_ops.getPostfix();
-    } else
-        return QString();
+    return mTonemappingOptions ? mTonemappingOptions->getPostfix() : QString();
 }
 
 QString LdrViewer::getExifComment()
@@ -212,8 +201,11 @@ QString LdrViewer::getExifComment()
     {
         TMOptionsOperations tm_ops(mTonemappingOptions);
         return tm_ops.getExifComment();
-    } else
+    }
+    else
+    {
         return QString();
+    }
 }
 
 void LdrViewer::updatePixmap()
@@ -223,16 +215,9 @@ void LdrViewer::updatePixmap()
 #endif
 
     QScopedPointer<QImage> temp_qimage( fromLDRPFStoQImage(getFrame()) );
-    QScopedPointer<QImage> xformed_qimage( doCMSTransform(temp_qimage.data(), false, false) );
 
-    if ( !xformed_qimage )
-    {
-        mPixmap->setPixmap(QPixmap::fromImage(*temp_qimage));
-    }
-    else
-    {
-        mPixmap->setPixmap(QPixmap::fromImage(*xformed_qimage));
-    }
+    doCMSTransform(*temp_qimage, false, false);
+    mPixmap->setPixmap(QPixmap::fromImage(*temp_qimage));
 
     informativeLabel->setText( tr("LDR image [%1 x %2]").arg(getWidth()).arg(getHeight()) );
 }
@@ -266,19 +251,17 @@ float LdrViewer::getMinLuminanceValue()
 void LdrViewer::doSoftProofing(bool doGamutCheck)
 {
     QScopedPointer<QImage> src_image( fromLDRPFStoQImage(getFrame()) );
-    QScopedPointer<QImage> image( doCMSTransform(src_image.data(), true, doGamutCheck) );
-    if (image.data() != NULL)
+    if ( doCMSTransform(*src_image, true, doGamutCheck) )
     {
-        mPixmap->setPixmap(QPixmap::fromImage(*image));
+        mPixmap->setPixmap(QPixmap::fromImage(*src_image));
     }
 }
 
 void LdrViewer::undoSoftProofing()
 {
     QScopedPointer<QImage> src_image( fromLDRPFStoQImage(getFrame()) );
-    QScopedPointer<QImage> image( doCMSTransform(src_image.data(), false, false) );
-    if (image.data() != NULL)
+    if ( doCMSTransform(*src_image, false, false) )
     {
-        mPixmap->setPixmap(QPixmap::fromImage(*image));
+        mPixmap->setPixmap(QPixmap::fromImage(*src_image));
     }
 }
