@@ -1,7 +1,8 @@
-/**
- * This file is a part of LuminanceHDR package.
+/*
+ * This file is a part of Luminance HDR package.
  * ---------------------------------------------------------------------- 
  * Copyright (C) 2006,2007,2008 Giuseppe Rota
+ * Copyright (C) 2010-2012 Daniel Kaneider, Davide Anastasia
  * 
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,16 +18,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * ---------------------------------------------------------------------- 
- * 
- * @author Daniel Kaneider <danielkaneider@users.sourceforge.net>
  *  
  */
 
+//! @author Daniel Kaneider <danielkaneider@users.sourceforge.net>
+
 #include <math.h>
 
 #if defined(_MSC_VER)
-	#include "msvc/math.h"
+#include "msvc/math.h"
+#elif defined(__FreeBSD__)
+#include "freebsd/math.h"
 #endif
-#if defined(__FreeBSD__)
-	#include "freebsd/math.h"
-#endif
\ No newline at end of file
