@@ -26,8 +26,8 @@
 #define MSVC_MATH_H
 
 #define _USE_MATH_DEFINES
-#include <math.h> // re-include here
-#include <float.h> // for _finite
+#include <math.h>   // re-include here
+#include <float.h>  // for _finite
 
 #define exp2f(x)        (powf(2.0f, x))
 #define log2(x)        (log(x)  / M_LN2)
@@ -37,17 +37,9 @@
 #define round(d)       ((d>0) ? int(d+0.5) : int(d-0.5))
 #define finite(x)       (_finite(x))
 
-#define isnan(x) (x != x)
-#define isnanf(x) (x != x)
+#define isnan(x) _isnan(x)
+#define isnanf(x) _isnanf(x)
 
-#define fmax max
-#define fmaxf max
-#define fmin min
-#define fminf min
 #pragma warning (disable:4996)
 
-#ifndef snprintf
-	#define snprintf sprintf_s
-#endif
-
 #endif  // MSVC_MATH_H
